@@ -8,7 +8,6 @@ Includes
 #include "Winamp2.h"
 #include "WinampSettingsDlg.h"
 #include "In2.h"
-#include "APELink.h"
 #include "CharacterHelper.h"
 #include <afxmt.h>
 #include "wasabi/Wasabi.h"
@@ -47,8 +46,8 @@ In_Module g_APEWinampPluginModule =
 {
     IN_VER,                                                        // the version (defined in in2.h)
     PLUGIN_NAME,                                                   // the name of the plugin (defined in all.h)
-    0,                                                             // handle to the main window
-    0,                                                             // handle to the dll instance
+    APE_NULL,                                                      // handle to the main window
+    APE_NULL,                                                      // handle to the dll instance
     "APE\0Monkey's Audio File (*.APE)\0"                           // the file type(s) supported
     "MAC\0Monkey's Audio File (*.MAC)\0"
     "APL\0Monkey's Audio File (*.APL)\0",
@@ -71,11 +70,11 @@ In_Module g_APEWinampPluginModule =
     CAPEWinampPlugin::SetOutputTime,
     CAPEWinampPlugin::SetVolume,
     CAPEWinampPlugin::SetPan,
-    0, 0, 0, 0, 0, 0, 0, 0, 0,                                     // vis stuff
-    0, 0,                                                          // dsp stuff
-    0,                                                             // Set_EQ function
-    NULL,                                                          // setinfo
-    0                                                              // out_mod
+    APE_NULL, APE_NULL, APE_NULL, APE_NULL, APE_NULL, APE_NULL, APE_NULL, APE_NULL, APE_NULL, // vis stuff
+    APE_NULL, APE_NULL,                                            // dsp stuff
+    APE_NULL,                                                      // Set_EQ function
+    APE_NULL,                                                      // setinfo
+    APE_NULL                                                       // out_mod
 };
 
 /**************************************************************************************************
@@ -99,7 +98,7 @@ Plays a file (called once on the start of a file)
 int CAPEWinampPlugin::Play(char * pFilename)
 {
     // reset or initialize any public variables
-    CSmartPtr<str_utfn> spFilename(CAPECharacterHelper::GetUTF16FromANSI(pFilename), TRUE);
+    CSmartPtr<str_utfn> spFilename(CAPECharacterHelper::GetUTF16FromANSI(pFilename), true);
     _tcscpy_s(m_cCurrentFilename, APE_MAX_PATH, spFilename);
 
     m_nPaused = 0;
@@ -109,7 +108,7 @@ int CAPEWinampPlugin::Play(char * pFilename)
     // open the file
     int nErrorCode = 0;
     m_spAPEDecompress.Assign(CreateIAPEDecompress(m_cCurrentFilename, &nErrorCode, true, true, false));
-    if ((m_spAPEDecompress == NULL) || (nErrorCode != ERROR_SUCCESS))
+    if ((m_spAPEDecompress == APE_NULL) || (nErrorCode != ERROR_SUCCESS))
         return -1;
 
     // quit if it's a zero length file
@@ -120,20 +119,21 @@ int CAPEWinampPlugin::Play(char * pFilename)
     }
 
     // version check
-    if (m_spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_FILE_VERSION) > MAC_FILE_VERSION_NUMBER)
+    if (m_spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_FILE_VERSION) > APE_FILE_VERSION_NUMBER)
     {
         TCHAR cAPEFileVersion[32]; _stprintf_s(cAPEFileVersion, 32, _T("%.2f"), static_cast<double>(m_spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_FILE_VERSION)) / static_cast<double>(1000));
 
         TCHAR cMessage[1024];
-        _stprintf_s(cMessage, 1024, _T("You are attempting to play an APE file that was encoded with a version of Monkey's Audio which is newer than the installed APE plug-in.  There is a very high likelyhood that this will not work properly.  Please download and install the newest Monkey's Audio plug-in to remedy this problem.\r\n\r\nPlug-in version: %s\r\nAPE file version: %s"), MAC_VERSION_STRING, cAPEFileVersion);
+        _stprintf_s(cMessage, 1024, _T("You are attempting to play an APE file that was encoded with a version of Monkey's Audio which is newer than the installed APE plug-in. There is a very high likelyhood that this will not work properly. Please download and install the newest Monkey's Audio plug-in to remedy this problem.\r\n\r\nPlug-in version: %s\r\nAPE file version: %s"),
+            APE_VERSION_STRING, cAPEFileVersion);
         ::MessageBox(g_APEWinampPluginModule.hMainWindow, cMessage, _T("Update APE Plugin"), MB_OK | MB_ICONERROR);
     }
 
     // see if it's a stream
-    g_APEWinampPluginModule.is_seekable = TRUE;
+    g_APEWinampPluginModule.is_seekable = true;
 
     // set the "scaled" bps
-    if (GetSettings()->m_bScaleOutput == TRUE)
+    if (GetSettings()->m_bScaleOutput)
     {
         m_nScaledBitsPerSample = SCALED_BITS;
         m_nScaledBytesPerSample = (SCALED_BITS / 8);
@@ -170,8 +170,8 @@ int CAPEWinampPlugin::Play(char * pFilename)
     // create the new thread
     m_nKillDecodeThread = 0;
     unsigned long nThreadID;
-    m_hDecodeThread = static_cast<HANDLE>(CreateThread(NULL, 0, static_cast<LPTHREAD_START_ROUTINE>(DecodeThread), static_cast<void *>(&m_nKillDecodeThread), 0, &nThreadID));
-    if (m_hDecodeThread == NULL)
+    m_hDecodeThread = static_cast<HANDLE>(CreateThread(APE_NULL, 0, static_cast<LPTHREAD_START_ROUTINE>(DecodeThread), static_cast<void *>(&m_nKillDecodeThread), 0, &nThreadID));
+    if (m_hDecodeThread == APE_NULL)
     {
         m_spAPEDecompress.Delete();
         return -1;
@@ -241,12 +241,12 @@ BOOL CAPEWinampPlugin::CheckBufferForSilence(void * pBuffer, const uint32 nSampl
             nSum += static_cast<uint32>(abs(*pData));
     }
 
-    nSum /= ape_max(nSamples, 1);
+    nSum /= APE_MAX(nSamples, 1);
 
     if (nSum > 64)
-        return FALSE;
+        return false;
     else
-        return TRUE;
+        return true;
 }
 
 /**************************************************************************************************
@@ -257,20 +257,20 @@ long CAPEWinampPlugin::ScaleBuffer(IAPEDecompress * pAPEDecompress, unsigned cha
     if (pAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_BITS_PER_SAMPLE) == 8)
     {
         unsigned char * pBuffer8 = &pBuffer[nBlocks * pAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_CHANNELS) - 1];
-        __int16 * pBuffer16 = reinterpret_cast<__int16 *>(&pBuffer[nBlocks * pAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_CHANNELS) * 2 - 2]);
+        int16_t * pBuffer16 = reinterpret_cast<int16_t *>(&pBuffer[nBlocks * pAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_CHANNELS) * 2 - 2]);
         while (pBuffer8 >= pBuffer)
         {
-            *pBuffer16-- = static_cast<__int16>((long(*pBuffer8--) - 128) << 8);
+            *pBuffer16-- = static_cast<int16_t>((long(*pBuffer8--) - 128) << 8);
         }
     }
     else if (pAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_BITS_PER_SAMPLE) == 24)
     {
         unsigned char * pBuffer24 = pBuffer;
-        __int16 * pBuffer16 = reinterpret_cast<__int16 *>(pBuffer);
+        int16_t * pBuffer16 = reinterpret_cast<int16_t *>(pBuffer);
         long nElements = nBlocks * long(pAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_CHANNELS));
         for (long z = 0; z < nElements; z++, pBuffer16++, pBuffer24 += 3)
         {
-            *pBuffer16 = static_cast<__int16>(*(reinterpret_cast<long *>(pBuffer24)) >> 8);
+            *pBuffer16 = static_cast<int16_t>(*(reinterpret_cast<long *>(pBuffer24)) >> 8);
         }
     }
 
@@ -282,13 +282,13 @@ long CAPEWinampPlugin::ScaleFloatBuffer(IAPEDecompress * pAPEDecompress, unsigne
     if (pAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_BITS_PER_SAMPLE) == 32)
     {
         float * pBufferFloat = reinterpret_cast<float *>(pBuffer);
-        __int32 * pBuffer32 = reinterpret_cast<__int32 *>(pBuffer);
+        int32_t * pBuffer32 = reinterpret_cast<int32_t *>(pBuffer);
         long nElements = nBlocks * long(pAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_CHANNELS));
         for (long z = 0; z < nElements; z++, pBuffer32++, pBufferFloat++)
         {
             float fValue = *pBufferFloat;
             fValue *= 2147483647.0f;
-            *pBuffer32 = static_cast<__int32>(fValue);
+            *pBuffer32 = static_cast<int32_t>(fValue);
         }
     }
 
@@ -301,11 +301,11 @@ The decode thread
 DWORD WINAPI __stdcall CAPEWinampPlugin::DecodeThread(void * pbKillSwitch)
 {
     // variable declares
-    BOOL bDone = FALSE;
+    bool bDone = false;
     long nSilenceMS = 0;
 
     // the sample buffer...must be able to hold twice the original 1152 samples for DSP
-    CSmartPtr<unsigned char> spSampleBuffer(new unsigned char [static_cast<unsigned int>(1152 * 2 * m_spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_CHANNELS) * m_nScaledBytesPerSample)], TRUE);
+    CSmartPtr<unsigned char> spSampleBuffer(new unsigned char [static_cast<unsigned int>(1152 * 2 * m_spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_CHANNELS) * m_nScaledBytesPerSample)], true);
 
     // start the decoding loop
     while (!*(reinterpret_cast<int *>(pbKillSwitch)))
@@ -349,7 +349,7 @@ DWORD WINAPI __stdcall CAPEWinampPlugin::DecodeThread(void * pbKillSwitch)
         {
             // decompress the data
             int64 nBlocksDecoded = 0;
-            BOOL bSynched = TRUE;
+            bool bSynched = true;
             try
             {
                 // get the data
@@ -358,9 +358,9 @@ DWORD WINAPI __stdcall CAPEWinampPlugin::DecodeThread(void * pbKillSwitch)
             }
             catch(...)
             {
-                bSynched = FALSE;
+                bSynched = false;
 
-                if (GetSettings()->m_bIgnoreBitstreamErrors == FALSE)
+                if (GetSettings()->m_bIgnoreBitstreamErrors == false)
                 {
                     TCHAR cErrorTime[64];
                     int nSeconds = static_cast<int>(m_spAPEDecompress->GetInfo(IAPEDecompress::APE_DECOMPRESS_CURRENT_MS) / 1000); int nMinutes = nSeconds / 60; nSeconds = nSeconds % 60; int nHours = nMinutes / 60; nMinutes = nMinutes % 60;
@@ -373,7 +373,7 @@ DWORD WINAPI __stdcall CAPEWinampPlugin::DecodeThread(void * pbKillSwitch)
                         cErrorMessage,
                         1024,
                         _T("Monkey's Audio encountered an error at %s while decompressing the file '%s'.\r\n\r\n")
-                        _T("Please ensure that you are using the latest version of Monkey's Audio.  ")
+                        _T("Please ensure that you are using the latest version of Monkey's Audio. ")
                         _T("If this error persists using the latest version of Monkey's Audio, it is likely that the file has become corrupted.\r\n\r\n")
                         _T("Use the option 'Ignore Bitstream Errors' in the plug-in settings to not recieve this warning when Monkey's Audio encounters an error while decompressing."),
                         cErrorTime, m_cCurrentFilename
@@ -381,7 +381,7 @@ DWORD WINAPI __stdcall CAPEWinampPlugin::DecodeThread(void * pbKillSwitch)
 
                     MessageBox(g_APEWinampPluginModule.hMainWindow, cErrorMessage, _T("Monkey's Audio Decompression Error"), MB_OK | MB_ICONERROR);
 
-                    bDone = TRUE;
+                    bDone = true;
                     continue;
                 }
             }
@@ -389,16 +389,16 @@ DWORD WINAPI __stdcall CAPEWinampPlugin::DecodeThread(void * pbKillSwitch)
             // set the done flag if there was nothing decompressed
             if (nBlocksDecoded == 0)
             {
-                bDone = TRUE;
+                bDone = true;
                 continue;
             }
 
             // do any MAC processing
-            if (GetSettings()->m_bScaleOutput == TRUE)
+            if (GetSettings()->m_bScaleOutput)
             {
                 ScaleBuffer(m_spAPEDecompress, spSampleBuffer, long(nBlocksDecoded));
             }
-            else if (m_spAPEDecompress->GetInfo(APE::IAPEDecompress::APE_INFO_FORMAT_FLAGS) & MAC_FORMAT_FLAG_FLOATING_POINT)
+            else if (m_spAPEDecompress->GetInfo(APE::IAPEDecompress::APE_INFO_FORMAT_FLAGS) & APE_FORMAT_FLAG_FLOATING_POINT)
             {
                 ScaleFloatBuffer(m_spAPEDecompress, spSampleBuffer, long(nBlocksDecoded));
             }
@@ -413,9 +413,9 @@ DWORD WINAPI __stdcall CAPEWinampPlugin::DecodeThread(void * pbKillSwitch)
                 nBytesDecoded = static_cast<long>(nBlocksDecoded) * m_nScaledBytesPerSample * static_cast<long>(m_spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_CHANNELS));
             }
 
-            if (GetSettings()->m_bSuppressSilence == TRUE)
+            if (GetSettings()->m_bSuppressSilence)
             {
-                if (CheckBufferForSilence(spSampleBuffer, static_cast<uint32>(nBytesDecoded / m_nScaledBytesPerSample)) == FALSE)
+                if (CheckBufferForSilence(spSampleBuffer, static_cast<uint32>(nBytesDecoded / m_nScaledBytesPerSample)) == false)
                     nSilenceMS = 0;
                 else
                     nSilenceMS += static_cast<long>(nBlocksDecoded * 1000) / static_cast<long>(m_spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_SAMPLE_RATE));
@@ -436,7 +436,7 @@ DWORD WINAPI __stdcall CAPEWinampPlugin::DecodeThread(void * pbKillSwitch)
             }
             else
             {
-                bSynched = FALSE;
+                bSynched = false;
             }
 
             // update the VBR display
@@ -511,13 +511,13 @@ void CAPEWinampPlugin::BuildDescriptionStringFromFilename(CString & strBuffer, c
 
 void CAPEWinampPlugin::BuildDescriptionString(CString & strBuffer, IAPETag * pAPETag, const str_utfn * pFilename)
 {
-    if (pAPETag == NULL)
+    if (pAPETag == APE_NULL)
     {
         BuildDescriptionStringFromFilename(strBuffer, pFilename);
         return;
     }
 
-    if (pAPETag->GetHasID3Tag() == FALSE && pAPETag->GetHasAPETag() == FALSE)
+    if (pAPETag->GetHasID3Tag() == false && pAPETag->GetHasAPETag() == false)
     {
         BuildDescriptionStringFromFilename(strBuffer, pFilename);
         return;
@@ -557,18 +557,18 @@ void CAPEWinampPlugin::GetFileInformation(char * pFilename, char * pTitle, int *
     if (!pFilename || !*pFilename)
     {
         // currently playing file
-        spAPEDecompress.Assign(m_spAPEDecompress, FALSE, FALSE);
+        spAPEDecompress.Assign(m_spAPEDecompress, false, false);
         strFilename = m_cCurrentFilename;
     }
     else
     {
         // different file
-        CSmartPtr<wchar_t> spUTF16(CAPECharacterHelper::GetUTF16FromANSI(pFilename), TRUE);
-        spAPEDecompress.Assign(CreateIAPEDecompress(spUTF16, NULL, true, true, false));
+        CSmartPtr<wchar_t> spUTF16(CAPECharacterHelper::GetUTF16FromANSI(pFilename), true);
+        spAPEDecompress.Assign(CreateIAPEDecompress(spUTF16, APE_NULL, true, true, false));
         strFilename = spUTF16;
     }
 
-    if (spAPEDecompress != NULL)
+    if (spAPEDecompress != APE_NULL)
     {
         if (pLengthMS)
         {
@@ -580,7 +580,7 @@ void CAPEWinampPlugin::GetFileInformation(char * pFilename, char * pTitle, int *
             CString strDisplay = GetSettings()->m_strFileDisplayMethod;
             BuildDescriptionString(strDisplay, GET_TAG(spAPEDecompress), strFilename);
 
-            CSmartPtr<char> spDisplayANSI(CAPECharacterHelper::GetANSIFromUTF16(strDisplay), TRUE);
+            CSmartPtr<char> spDisplayANSI(CAPECharacterHelper::GetANSIFromUTF16(strDisplay), true);
             strncpy_s(pTitle, GETFILEINFO_TITLE_LENGTH, spDisplayANSI, _TRUNCATE);
         }
     }
@@ -682,7 +682,7 @@ extern "C"
     // use ugly statics since Winamp is built around global variables
     static CString s_strFilename;
     static CSmartPtr<IAPEDecompress> s_spAPEDecompress;
-    static HANDLE s_hTimer = NULL;
+    static HANDLE s_hTimer = APE_NULL;
     static CCriticalSection s_Lock;
 
     // forward declares to avoid Clang warnings
@@ -699,9 +699,9 @@ extern "C"
     static void KillMediaTimer()
     {
         CSingleLock Lock(&s_Lock);
-        if (s_hTimer != NULL)
+        if (s_hTimer != APE_NULL)
         {
-            BOOL bResult = DeleteTimerQueueTimer(NULL, s_hTimer, NULL);
+            BOOL bResult = DeleteTimerQueueTimer(APE_NULL, s_hTimer, APE_NULL);
             if (bResult == 0)
             {
                 DWORD dwError = GetLastError();
@@ -715,7 +715,7 @@ extern "C"
 
             // clear the timer
             if (bResult)
-                s_hTimer = NULL;
+                s_hTimer = APE_NULL;
         }
     }
 
@@ -723,7 +723,7 @@ extern "C"
     {
         // check if the timer has already been deleted and don't run in that case
         CSingleLock Lock(&s_Lock);
-        if (s_hTimer != NULL)
+        if (s_hTimer != APE_NULL)
         {
             s_spAPEDecompress.Delete();
             KillMediaTimer();
@@ -734,7 +734,7 @@ extern "C"
     {
         CSingleLock Lock(&s_Lock);
         KillMediaTimer();
-        CreateTimerQueueTimer(&s_hTimer, NULL, static_cast<WAITORTIMERCALLBACK>(TimerProc), NULL, 3000, 0, WT_EXECUTEINTIMERTHREAD);
+        CreateTimerQueueTimer(&s_hTimer, APE_NULL, static_cast<WAITORTIMERCALLBACK>(TimerProc), APE_NULL, 3000, 0, WT_EXECUTEINTIMERTHREAD);
     }
 
     // return 1 if you want winamp to show it's own file info dialogue, 0 if you want to show your own (via In_Module.InfoBox)
@@ -754,17 +754,17 @@ extern "C"
         CSingleLock Lock(&s_Lock);
 
         // load the file
-        CSmartPtr<wchar_t> spUTF16(CAPECharacterHelper::GetUTF16FromANSI(filename), TRUE);
-        if ((s_spAPEDecompress == NULL) || (spUTF16 != s_strFilename))
+        CSmartPtr<wchar_t> spUTF16(CAPECharacterHelper::GetUTF16FromANSI(filename), true);
+        if ((s_spAPEDecompress == APE_NULL) || (spUTF16 != s_strFilename))
         {
-            s_spAPEDecompress.Assign(CreateIAPEDecompress(spUTF16, NULL, false, true, false));
+            s_spAPEDecompress.Assign(CreateIAPEDecompress(spUTF16, APE_NULL, false, true, false));
             s_strFilename = spUTF16;
         }
 
         IAPETag * pTag = GET_TAG(s_spAPEDecompress);
-        if (pTag != NULL)
+        if (pTag != APE_NULL)
         {
-            CSmartPtr<wchar_t> spValue(CAPECharacterHelper::GetUTF16FromANSI(val), TRUE);
+            CSmartPtr<wchar_t> spValue(CAPECharacterHelper::GetUTF16FromANSI(val), true);
 
             if (strcmp(metadata, "artist") == 0)
                 pTag->SetFieldString(APE_TAG_FIELD_ARTIST, spValue);
@@ -800,10 +800,10 @@ extern "C"
         CSingleLock Lock(&s_Lock);
 
         int nResult = 0;
-        if (s_spAPEDecompress != NULL)
+        if (s_spAPEDecompress != APE_NULL)
         {
             IAPETag * pTag = GET_TAG(s_spAPEDecompress);
-            if (pTag != NULL)
+            if (pTag != APE_NULL)
             {
                 if (pTag->Save(false) == ERROR_SUCCESS)
                     nResult = 1;
@@ -821,7 +821,7 @@ extern "C"
         KillMediaTimer(); // stop the cleanup timer (or else it can run while we're working)
 
         // on startup, type is queried for
-        if (((Info.pFilename == NULL) || (Info.pFilename[0] == 0)) &&
+        if (((Info.pFilename == APE_NULL) || (Info.pFilename[0] == 0)) &&
             (strcmp(Info.pMetaData, "type") == 0))
         {
             strcpy_s(Info.pReturn, static_cast<size_t>(Info.nReturnBytes), "ape");
@@ -829,10 +829,10 @@ extern "C"
         }
 
         // load the file
-        CSmartPtr<wchar_t> spUTF16(CAPECharacterHelper::GetUTF16FromANSI(Info.pFilename), TRUE);
-        if ((s_spAPEDecompress == NULL) || (spUTF16 != s_strFilename))
+        CSmartPtr<wchar_t> spUTF16(CAPECharacterHelper::GetUTF16FromANSI(Info.pFilename), true);
+        if ((s_spAPEDecompress == APE_NULL) || (spUTF16 != s_strFilename))
         {
-            s_spAPEDecompress.Assign(CreateIAPEDecompress(spUTF16, NULL, false, true, false));
+            s_spAPEDecompress.Assign(CreateIAPEDecompress(spUTF16, APE_NULL, false, true, false));
             s_strFilename = spUTF16;
         }
 
@@ -842,15 +842,15 @@ extern "C"
         {
             if (strcmp(Info.pMetaData, "artist") == 0)
             {
-                pTag->GetFieldString(APE_TAG_FIELD_ARTIST, Info.pReturn, &Info.nReturnBytes, FALSE);
+                pTag->GetFieldString(APE_TAG_FIELD_ARTIST, Info.pReturn, &Info.nReturnBytes, false);
             }
             else if (strcmp(Info.pMetaData, "album") == 0)
             {
-                pTag->GetFieldString(APE_TAG_FIELD_ALBUM, Info.pReturn, &Info.nReturnBytes, FALSE);
+                pTag->GetFieldString(APE_TAG_FIELD_ALBUM, Info.pReturn, &Info.nReturnBytes, false);
             }
             else if (strcmp(Info.pMetaData, "title") == 0)
             {
-                pTag->GetFieldString(APE_TAG_FIELD_TITLE, Info.pReturn, &Info.nReturnBytes, FALSE);
+                pTag->GetFieldString(APE_TAG_FIELD_TITLE, Info.pReturn, &Info.nReturnBytes, false);
             }
             else if (strcmp(Info.pMetaData, "type") == 0)
             {
@@ -858,15 +858,15 @@ extern "C"
             }
             else if (strcmp(Info.pMetaData, "comment") == 0)
             {
-                pTag->GetFieldString(APE_TAG_FIELD_COMMENT, Info.pReturn, &Info.nReturnBytes, FALSE);
+                pTag->GetFieldString(APE_TAG_FIELD_COMMENT, Info.pReturn, &Info.nReturnBytes, false);
             }
             else if (strcmp(Info.pMetaData, "year") == 0)
             {
-                pTag->GetFieldString(APE_TAG_FIELD_YEAR, Info.pReturn, &Info.nReturnBytes, FALSE);
+                pTag->GetFieldString(APE_TAG_FIELD_YEAR, Info.pReturn, &Info.nReturnBytes, false);
             }
             else if (strcmp(Info.pMetaData, "genre") == 0)
             {
-                pTag->GetFieldString(APE_TAG_FIELD_GENRE, Info.pReturn, &Info.nReturnBytes, FALSE);
+                pTag->GetFieldString(APE_TAG_FIELD_GENRE, Info.pReturn, &Info.nReturnBytes, false);
             }
             else if (strcmp(Info.pMetaData, "length") == 0)
             {
@@ -875,27 +875,27 @@ extern "C"
             }
             else if (strcmp(Info.pMetaData, "track") == 0)
             {
-                pTag->GetFieldString(APE_TAG_FIELD_TRACK, Info.pReturn, &Info.nReturnBytes, FALSE);
+                pTag->GetFieldString(APE_TAG_FIELD_TRACK, Info.pReturn, &Info.nReturnBytes, false);
             }
             else if (strcmp(Info.pMetaData, "disc") == 0)
             {
-                pTag->GetFieldString(APE_TAG_FIELD_DISC, Info.pReturn, &Info.nReturnBytes, FALSE);
+                pTag->GetFieldString(APE_TAG_FIELD_DISC, Info.pReturn, &Info.nReturnBytes, false);
             }
             else if (strcmp(Info.pMetaData, "albumartist") == 0)
             {
-                pTag->GetFieldString(APE_TAG_FIELD_ALBUM_ARTIST, Info.pReturn, &Info.nReturnBytes, FALSE);
+                pTag->GetFieldString(APE_TAG_FIELD_ALBUM_ARTIST, Info.pReturn, &Info.nReturnBytes, false);
             }
             else if (strcmp(Info.pMetaData, "composer") == 0)
             {
-                pTag->GetFieldString(APE_TAG_FIELD_COMPOSER, Info.pReturn, &Info.nReturnBytes, FALSE);
+                pTag->GetFieldString(APE_TAG_FIELD_COMPOSER, Info.pReturn, &Info.nReturnBytes, false);
             }
             else if (strcmp(Info.pMetaData, "publisher") == 0)
             {
-                pTag->GetFieldString(APE_TAG_FIELD_PUBLISHER, Info.pReturn, &Info.nReturnBytes, FALSE);
+                pTag->GetFieldString(APE_TAG_FIELD_PUBLISHER, Info.pReturn, &Info.nReturnBytes, false);
             }
             else if (strcmp(Info.pMetaData, "bpm") == 0)
             {
-                pTag->GetFieldString(APE_TAG_FIELD_BPM, Info.pReturn, &Info.nReturnBytes, FALSE);
+                pTag->GetFieldString(APE_TAG_FIELD_BPM, Info.pReturn, &Info.nReturnBytes, false);
             }
             else if (_stricmp(Info.pMetaData, "formatinformation") == 0)
             {
@@ -903,8 +903,8 @@ extern "C"
                 CString strLine;
 
                 // get the compression level
-                str_utfn cCompressionLevel[256]; APE_CLEAR(cCompressionLevel);
-                GetAPECompressionLevelName(static_cast<int>(s_spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_COMPRESSION_LEVEL)), cCompressionLevel, 256, false);
+                str_utfn cCompressionLevel[16]; APE_CLEAR(cCompressionLevel);
+                GetAPECompressionLevelName(static_cast<int>(s_spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_COMPRESSION_LEVEL)), cCompressionLevel, 16, false);
 
                 // overall
                 strLine.Format(_T("Monkey's Audio %.2f (%s)"),
@@ -916,13 +916,13 @@ extern "C"
                     static_cast<double>(s_spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_SAMPLE_RATE)) / static_cast<double>(1000),
                     static_cast<int>(s_spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_BITS_PER_SAMPLE)),
                     static_cast<int>(s_spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_CHANNELS)));
-                if (s_spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_FORMAT_FLAGS) & MAC_FORMAT_FLAG_AIFF)
+                if (s_spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_FORMAT_FLAGS) & APE_FORMAT_FLAG_AIFF)
                     strLine += _T(", AIFF");
                 strFormat += strLine + _T("\r\n");
 
                 // length
                 strLine.Format(_T("Length: %s (%I64d blocks)"),
-                    static_cast<LPCTSTR>(FormatDuration(static_cast<double>(s_spAPEDecompress->GetInfo(IAPEDecompress::APE_DECOMPRESS_LENGTH_MS)) / 1000.0, FALSE)),
+                    static_cast<LPCTSTR>(FormatDuration(static_cast<double>(s_spAPEDecompress->GetInfo(IAPEDecompress::APE_DECOMPRESS_LENGTH_MS)) / 1000.0, false)),
                     s_spAPEDecompress->GetInfo(IAPEDecompress::APE_DECOMPRESS_TOTAL_BLOCKS));
                 strFormat += strLine + _T("\r\n");
 
@@ -937,9 +937,8 @@ extern "C"
                 strLine.Format(_T("Compression: %.2f%%"), static_cast<double>(s_spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_AVERAGE_BITRATE) * 100) / static_cast<double>(s_spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_DECOMPRESSED_BITRATE)));
                 strFormat += strLine + _T("\r\n");
 
-                str_ansi * pFormatANSI = CAPECharacterHelper::GetANSIFromUTF16(strFormat);
-                strncpy_s(Info.pReturn, static_cast<size_t>(Info.nReturnBytes), pFormatANSI, static_cast<size_t>(Info.nReturnBytes));
-                delete [] pFormatANSI;
+                CSmartPtr<str_ansi> spFormatANSI(CAPECharacterHelper::GetANSIFromUTF16(strFormat), true);
+                strncpy_s(Info.pReturn, static_cast<size_t>(Info.nReturnBytes), spFormatANSI, static_cast<size_t>(Info.nReturnBytes));
             }
             else
             {
@@ -973,22 +972,22 @@ extern "C" int APE_GetAlbumArt(const wchar_t * filename, const wchar_t * type, v
     CSmartPtr<IAPEDecompress> spAPEDecompress;
 
     // load the file
-    spAPEDecompress.Assign(CreateIAPEDecompress(filename, NULL, false, true, false));
+    spAPEDecompress.Assign(CreateIAPEDecompress(filename, APE_NULL, false, true, false));
 
     // get the tag
     IAPETag * pTag = GET_TAG(spAPEDecompress);
-    if (pTag != NULL)
+    if (pTag != APE_NULL)
     {
         CAPETagField * pTagImage = pTag->GetTagField(APE_TAG_FIELD_COVER_ART_FRONT);
-        if ((pTagImage != NULL) && (pTagImage->GetFieldSize() > 0))
+        if ((pTagImage != APE_NULL) && (pTagImage->GetFieldSize() > 0))
         {
             *len = static_cast<size_t>(pTagImage->GetFieldSize());
-            CSmartPtr<BYTE> spBuffer(new BYTE[*len], true);
+            CSmartPtr<BYTE> spBuffer(new BYTE [*len], true);
 
             int nBufferBytes = static_cast<int>(*len);
             if (pTag->GetFieldBinary(APE_TAG_FIELD_COVER_ART_FRONT, spBuffer, &nBufferBytes) == ERROR_SUCCESS)
             {
-                BYTE * pImage = NULL; int nImageBytes = -1;
+                BYTE * pImage = APE_NULL; int nImageBytes = -1;
                 for (int nSearch = 0; nSearch < nBufferBytes; nSearch++)
                 {
                     if (spBuffer[nSearch] == 0)
@@ -999,14 +998,12 @@ extern "C" int APE_GetAlbumArt(const wchar_t * filename, const wchar_t * type, v
                     }
                 }
 
-                if (pImage != NULL)
+                if (pImage != APE_NULL)
                 {
-                    // load the filename
-                    CString strFilename;
-                    strFilename = CAPECharacterHelper::GetUTF16FromUTF8(static_cast<APE::str_utf8 *>(spBuffer));
-
                     // get the extension
-                    CString strExtension = strFilename.Right(strFilename.GetLength() - strFilename.ReverseFind('.') - 1);
+                    CString strExtension = CAPECharacterHelper::GetUTF16FromUTF8(static_cast<APE::str_utf8*>(spBuffer));
+                    if (strExtension.Find('.') >= 0)
+                        strExtension = strExtension.Right(strExtension.GetLength() - strExtension.ReverseFind('.') - 1);
 
                     // get the mime type
                     *mime_type = static_cast<wchar_t *>(Wasabi_Malloc((static_cast<size_t>(strExtension.GetLength()) + 1) * 2));
@@ -1040,7 +1037,7 @@ extern "C" int APE_SetAlbumArt(const wchar_t * filename, const wchar_t * type, v
     CSmartPtr<IAPEDecompress> spAPEDecompress;
 
     // load the file
-    spAPEDecompress.Assign(CreateIAPEDecompress(filename, NULL, false, true, false));
+    spAPEDecompress.Assign(CreateIAPEDecompress(filename, APE_NULL, false, true, false));
 
     // we don't currently support saving art, maybe someday...
     // if anyone can help me figure out how to make this run in the debugger, please share
@@ -1061,10 +1058,10 @@ extern "C" int APE_DeleteAlbumArt(const wchar_t * filename, const wchar_t * type
     CSmartPtr<IAPEDecompress> spAPEDecompress;
 
     // load the file
-    spAPEDecompress.Assign(CreateIAPEDecompress(filename, NULL, false, true, false));
+    spAPEDecompress.Assign(CreateIAPEDecompress(filename, APE_NULL, false, true, false));
 
     IAPETag * pTag = GET_TAG(spAPEDecompress);
-    if (pTag != NULL)
+    if (pTag != APE_NULL)
     {
         // remove cover art
         pTag->RemoveField(APE_TAG_FIELD_COVER_ART_FRONT);
