@@ -1,10 +1,8 @@
 #include "All.h"
-#define APE_ENABLE_TAG_FOOTER
 #include "APETag.h"
 #include "CharacterHelper.h"
 #include "IO.h"
 #include "GlobalFunctions.h"
-#include "IO.h"
 
 namespace APE
 {
@@ -15,11 +13,12 @@ CAPETagField
 CAPETagField::CAPETagField(const str_utfn * pFieldName, const void * pFieldValue, int nFieldBytes, int nFlags)
 {
     // field name
-    m_spFieldNameUTF16.Assign(new str_utfn [wcslen(pFieldName) + 1], true);
-    memcpy(m_spFieldNameUTF16, pFieldName, (wcslen(pFieldName) + 1) * sizeof(str_utfn));
+    size_t nFieldNameLength = wcslen(pFieldName);
+    m_spFieldNameUTF16.Assign(new str_utfn [nFieldNameLength + 1], true);
+    memcpy(m_spFieldNameUTF16, pFieldName, (nFieldNameLength + 1) * sizeof(m_spFieldNameUTF16[0]));
 
     // data (we'll always allocate two extra bytes and memset to 0 so we're safely NULL terminated)
-    m_nFieldValueBytes = ape_max(nFieldBytes, 0);
+    m_nFieldValueBytes = APE_MAX(nFieldBytes, 0);
     m_spFieldValue.Assign(new char [static_cast<size_t>(m_nFieldValueBytes) + 2], true);
     memset(m_spFieldValue, 0, static_cast<size_t>(m_nFieldValueBytes) + 2);
     if (m_nFieldValueBytes > 0)
@@ -51,12 +50,12 @@ const char * CAPETagField::GetFieldValue()
     return m_spFieldValue;
 }
 
-int CAPETagField::GetFieldValueSize()
+int CAPETagField::GetFieldValueSize() const
 {
     return m_nFieldValueBytes;
 }
 
-int CAPETagField::GetFieldFlags()
+int CAPETagField::GetFieldFlags() const
 {
     return m_nFieldFlags;
 }
@@ -82,17 +81,17 @@ int CAPETagField::SaveField(char * pBuffer, int nBytes)
     pBuffer += strlen(spFieldNameANSI) + 1;
     nBytes -= static_cast<int>(strlen(spFieldNameANSI)) + 1;
 
-    memcpy(pBuffer, m_spFieldValue, static_cast<size_t>(ape_min(m_nFieldValueBytes, nBytes)));
+    memcpy(pBuffer, m_spFieldValue, static_cast<size_t>(APE_MIN(m_nFieldValueBytes, nBytes)));
 
     return GetFieldSize();
 }
 
-bool CAPETagField::GetIsReadOnly()
+bool CAPETagField::GetIsReadOnly() const
 {
     return (m_nFieldFlags & TAG_FIELD_FLAG_READ_ONLY) ? true : false;
 }
 
-bool CAPETagField::GetIsUTF8Text()
+bool CAPETagField::GetIsUTF8Text() const
 {
     return ((m_nFieldFlags & TAG_FIELD_FLAG_DATA_TYPE_MASK) == TAG_FIELD_FLAG_DATA_TYPE_TEXT_UTF8) ? true : false;
 }
@@ -324,7 +323,8 @@ int CAPETag::Analyze()
     // we used to not load if we found an ID3 tag, but somebody sent me a file with both an ID3 tag and APE tag, so we'll try to parse that going forward
     {
         APE_TAG_FOOTER APETagFooter;
-        if (m_spIO->Seek(-static_cast<int>(APE_TAG_FOOTER_BYTES + (m_bHasID3Tag ? ID3_TAG_BYTES : 0)), SeekFileEnd) == ERROR_SUCCESS)
+        int nTagBytes = static_cast<int>(APE_TAG_FOOTER_BYTES + (m_bHasID3Tag ? ID3_TAG_BYTES : 0));
+        if (m_spIO->Seek(-nTagBytes, SeekFileEnd) == ERROR_SUCCESS)
         {
             unsigned int nBytesRead = 0;
             APETagFooter.Empty();
@@ -418,7 +418,7 @@ int CAPETag::GetFieldString(const str_utfn * pFieldName, str_ansi * pBuffer, int
         CSmartPtr<str_ansi> spANSI(bUTF8Encode ? reinterpret_cast<str_ansi *>(CAPECharacterHelper::GetUTF8FromUTF16(spUTF16)) : CAPECharacterHelper::GetANSIFromUTF16(spUTF16), true);
         if (static_cast<int>(strlen(spANSI)) > nOriginalCharacters)
         {
-            memset(pBuffer, 0, static_cast<size_t>(nOriginalCharacters) * sizeof(str_ansi));
+            memset(pBuffer, 0, static_cast<size_t>(nOriginalCharacters) * sizeof(pBuffer[0]));
             *pBufferCharacters = 0;
             nResult = ERROR_UNDEFINED;
         }
@@ -450,7 +450,7 @@ int CAPETag::GetFieldString(const str_utfn * pFieldName, str_utfn * pBuffer, int
         if (pAPETagField == APE_NULL)
         {
             // the field doesn't exist -- return an empty string
-            memset(pBuffer, 0, static_cast<size_t>(*pBufferCharacters) * sizeof(str_utfn));
+            memset(pBuffer, 0, static_cast<size_t>(*pBufferCharacters) * sizeof(pBuffer[0]));
             *pBufferCharacters = 0;
         }
         else if (pAPETagField->GetIsUTF8Text() || (m_nAPETagVersion < 2000))
@@ -473,11 +473,17 @@ int CAPETag::GetFieldString(const str_utfn * pFieldName, str_utfn * pBuffer, int
 
                 // get the number of characters
                 const int nCharacters = (static_cast<int>(wcslen(spUTF16)) + 1);
-                if ((nOutputCharacters + nCharacters + nListDelimiterCharacters) > *pBufferCharacters)
+
+                int nNeededCharacters = nOutputCharacters + nCharacters;
+                if (pBuffer[0] != 0)
+                    nNeededCharacters += nListDelimiterCharacters;
+
+                if (nNeededCharacters > *pBufferCharacters)
                 {
                     // we'll fail here, because it's not clear what would get returned (null termination, size, etc.)
                     // and we really don't want to cause buffer overruns on the client side
-                    *pBufferCharacters = (pAPETagField->GetFieldValueSize() + 1) + (nListDelimiterCharacters * 64); // worst-case scenario
+                    // we use (nListDelimiterCharacters - 1) since there's already a NULL delimiter in the field
+                    *pBufferCharacters = (pAPETagField->GetFieldValueSize() + 1) + ((nListDelimiterCharacters - 1) * 64); // worst-case scenario
                     nResult = ERROR_BAD_PARAMETER;
                     break;
                 }
@@ -517,12 +523,12 @@ int CAPETag::GetFieldString(const str_utfn * pFieldName, str_utfn * pBuffer, int
         else
         {
             // memset the whole buffer to NULL (so everything left over is NULL terminated)
-            memset(pBuffer, 0, static_cast<size_t>(*pBufferCharacters) * sizeof(str_utfn));
+            memset(pBuffer, 0, static_cast<size_t>(*pBufferCharacters) * sizeof(pBuffer[0]));
 
             // do a binary dump (need to convert from wchar's to bytes)
-            int nBufferBytes = (*pBufferCharacters - 1) * static_cast<int>(sizeof(str_utfn));
+            int nBufferBytes = (*pBufferCharacters - 1) * static_cast<int>(sizeof(pBuffer[0]));
             nResult = GetFieldBinary(pFieldName, pBuffer, &nBufferBytes);
-            *pBufferCharacters = (nBufferBytes / static_cast<int>(sizeof(str_utfn))) + 1;
+            *pBufferCharacters = (nBufferBytes / static_cast<int>(sizeof(pBuffer[0]))) + 1;
         }
     }
 
@@ -628,6 +634,11 @@ int CAPETag::GetAPETagVersion()
     return GetHasAPETag() ? m_nAPETagVersion : -1;
 }
 
+bool CAPETag::GetIOMatches(APE::CIO * pIO)
+{
+    return (m_spIO == pIO);
+}
+
 void CAPETag::SetIgnoreReadOnly(bool bIgnoreReadOnly)
 {
     m_bIgnoreReadOnly = bIgnoreReadOnly;
@@ -681,7 +692,7 @@ int CAPETag::LoadField(const char * pBuffer, int nMaximumBytes, int * pBytes)
     // name
     const int nNameCharacters = static_cast<int>(strlen(&pBuffer[nLocation]));
     CSmartPtr<str_utf8> spNameUTF8(new str_utf8 [static_cast<size_t>(nNameCharacters) + 1], true);
-    memcpy(spNameUTF8, &pBuffer[nLocation], (static_cast<size_t>(nNameCharacters) + 1) * sizeof(str_utf8));
+    memcpy(spNameUTF8, &pBuffer[nLocation], (static_cast<size_t>(nNameCharacters) + 1) * sizeof(spNameUTF8[0]));
     nLocation += nNameCharacters + 1;
     CSmartPtr<str_utfn> spNameUTF16(CAPECharacterHelper::GetUTF16FromUTF8(spNameUTF8.GetPtr()), true);
 
@@ -778,10 +789,10 @@ int CAPETag::SetFieldBinary(const str_utfn * pFieldName, const void * pFieldValu
     {
         const int nOriginalAllocatedFields = m_nAllocatedFields;
         m_nAllocatedFields *= 2;
-        m_nAllocatedFields = ape_max(m_nAllocatedFields, 256);
+        m_nAllocatedFields = APE_MAX(m_nAllocatedFields, 256);
         CAPETagField ** paryFields = new CAPETagField * [static_cast<size_t>(m_nAllocatedFields)];
         if (nOriginalAllocatedFields > 0)
-            memcpy(paryFields, m_aryFields, sizeof(CAPETagField *) * static_cast<size_t>(nOriginalAllocatedFields));
+            memcpy(paryFields, m_aryFields, sizeof(paryFields[0]) * static_cast<size_t>(nOriginalAllocatedFields));
         APE_SAFE_ARRAY_DELETE(m_aryFields)
         m_aryFields = paryFields;
     }
@@ -831,7 +842,7 @@ int CAPETag::RemoveField(int nIndex)
             delete m_aryFields[nIndex];
             m_aryFields[nIndex] = APE_NULL;
         }
-        memmove(&m_aryFields[nIndex], &m_aryFields[static_cast<size_t>(nIndex) + 1], (static_cast<size_t>(m_nAllocatedFields) - static_cast<size_t>(nIndex) - 1) * sizeof(CAPETagField *));
+        memmove(&m_aryFields[nIndex], &m_aryFields[static_cast<size_t>(nIndex) + 1], (static_cast<size_t>(m_nAllocatedFields) - static_cast<size_t>(nIndex) - 1) * sizeof(m_aryFields[0]));
         m_nFields--;
         return ERROR_SUCCESS;
     }
@@ -942,7 +953,7 @@ int CAPETag::GetFieldID3String(const str_utfn * pFieldName, char * pBuffer, int
     memset(pBuffer, 0, static_cast<size_t>(nBytes));
 
     int nStringLength = static_cast<int>(strlen(spBufferANSI.GetPtr()));
-    nStringLength = ape_min(nStringLength, nBytes);
+    nStringLength = APE_MIN(nStringLength, nBytes);
     memcpy(pBuffer, spBufferANSI.GetPtr(), static_cast<size_t>(nStringLength));
 
     return ERROR_SUCCESS;
@@ -951,7 +962,8 @@ int CAPETag::GetFieldID3String(const str_utfn * pFieldName, char * pBuffer, int
 int CAPETag::SortFields()
 {
     // sort the tag fields by size (so that the smallest fields are at the front of the tag)
-    qsort(m_aryFields, static_cast<size_t>(m_nFields), sizeof(CAPETagField *), CompareFields);
+    if (m_nFields > 1)
+        qsort(m_aryFields, static_cast<size_t>(m_nFields), sizeof(m_aryFields[0]), CompareFields);
 
     return ERROR_SUCCESS;
 }
