@@ -1,5 +1,4 @@
 #include "All.h"
-#define APE_ENABLE_MD5_ADD_DATA
 #include "MACLib.h"
 #include "APECompress.h"
 #include "APEDecompress.h"
@@ -22,7 +21,7 @@ using namespace APE;
 #define BLOCKS_PER_DECODE               9216
 
 IAPEDecompress * CreateIAPEDecompressCore(CAPEInfo * pAPEInfo, int nStartBlock, int nFinishBlock, int * pErrorCode);
-int DecompressCore(const APE::str_utfn * pInputFilename, const APE::str_utfn * pOutputFilename, int nOutputMode, int nCompressionLevel, IAPEProgressCallback * pProgressCallback, IAPEDecompress * pDecompress);
+int DecompressCore(const APE::str_utfn * pInputFilename, const APE::str_utfn * pOutputFilename, int nOutputMode, int nCompressionLevel, IAPEProgressCallback * pProgressCallback, IAPEDecompress * pDecompress, int nThreads);
 
 /**************************************************************************************************
 Functions to create the interfaces
@@ -42,9 +41,13 @@ IAPEDecompress * CreateIAPEDecompressCore(CAPEInfo * pAPEInfo, int nStartBlock,
             {
                 // create
                 const int nVersion = static_cast<int>(pAPEInfo->GetInfo(IAPEDecompress::APE_INFO_FILE_VERSION));
-                if ((nVersion >= 3930) && (nVersion <= MAC_FILE_VERSION_NUMBER))
+                if ((nVersion >= 3990) && (nVersion <= APE_FILE_VERSION_NUMBER))
                     spAPEDecompress.Assign(new CAPEDecompress(pErrorCode, pAPEInfo, nStartBlock, nFinishBlock));
+                else if (nVersion == 4110)
+                    spAPEDecompress.Assign(new CAPEDecompress(pErrorCode, pAPEInfo, nStartBlock, nFinishBlock)); // a few users have mailed me files with this version -- I don't know where they came from but they verify fine using this code
 #ifdef APE_BACKWARDS_COMPATIBILITY
+                else if ((nVersion >= 3930) && (nVersion <= APE_FILE_VERSION_NUMBER))
+                    spAPEDecompress.Assign(new CAPEDecompress(pErrorCode, pAPEInfo, nStartBlock, nFinishBlock));
                 else if (nVersion < 3930)
                     spAPEDecompress.Assign(new CAPEDecompressOld(pErrorCode, pAPEInfo, nStartBlock, nFinishBlock));
 #endif
@@ -257,25 +260,26 @@ int __stdcall FillRF64Header(RF64_HEADER * pWAVHeader, APE::int64 nAudioBytes, c
 
 int __stdcall GetAPEFileType(const APE::str_utfn * pInputFilename, APE::str_ansi cFileType[8])
 {
-    memset(&cFileType[0], 0, sizeof(APE::str_ansi) * 8);
+    memset(&cFileType[0], 0, sizeof(cFileType[0]) * 8);
 
     int nErrorCode = 0;
     CAPEInfo Info(&nErrorCode, pInputFilename, APE_NULL, false, true, false);
 
     // customize the type if we're AIFF, W64, etc.
-    if (Info.GetInfo(IAPEDecompress::APE_INFO_FORMAT_FLAGS) & MAC_FORMAT_FLAG_AIFF)
+    int64 nFormat = Info.GetInfo(IAPEDecompress::APE_INFO_FORMAT_FLAGS);
+    if (nFormat & APE_FORMAT_FLAG_AIFF)
     {
         strcpy_s(cFileType, 8, ".aiff");
     }
-    else if (Info.GetInfo(IAPEDecompress::APE_INFO_FORMAT_FLAGS) & MAC_FORMAT_FLAG_W64)
+    else if (nFormat & APE_FORMAT_FLAG_W64)
     {
         strcpy_s(cFileType, 8, ".w64");
     }
-    else if (Info.GetInfo(IAPEDecompress::APE_INFO_FORMAT_FLAGS) & MAC_FORMAT_FLAG_SND)
+    else if (nFormat & APE_FORMAT_FLAG_SND)
     {
         strcpy_s(cFileType, 8, ".snd");
     }
-    else if (Info.GetInfo(IAPEDecompress::APE_INFO_FORMAT_FLAGS) & MAC_FORMAT_FLAG_CAF)
+    else if (nFormat & APE_FORMAT_FLAG_CAF)
     {
         strcpy_s(cFileType, 8, ".caf");
     }
@@ -289,6 +293,7 @@ int __stdcall GetAPEFileType(const APE::str_utfn * pInputFilename, APE::str_ansi
 
 void __stdcall GetAPECompressionLevelName(int nCompressionLevel, APE::str_utfn * pCompressionLevel, size_t nBufferCharacters, bool bTitleCase)
 {
+    if (nBufferCharacters < 16) return; // just do a quick check since wcscpy_s crashes when you over copy
     if (bTitleCase)
     {
         switch (nCompressionLevel)
@@ -315,18 +320,34 @@ void __stdcall GetAPECompressionLevelName(int nCompressionLevel, APE::str_utfn *
     }
 }
 
+void __stdcall GetAPEModeName(APE::APE_MODES Mode, APE::str_utfn * pModeName, size_t nBufferCharacters, bool bActive)
+{
+    if (nBufferCharacters < 16) return; // just do a quick check since wcscpy_s crashes when you over copy
+    switch (Mode)
+    {
+        case MODE_COMPRESS: bActive ? wcscpy_s(pModeName, nBufferCharacters, L"Compressing") : wcscpy_s(pModeName, nBufferCharacters, L"Compress"); break;
+        case MODE_DECOMPRESS: bActive ? wcscpy_s(pModeName, nBufferCharacters, L"Decompressing") : wcscpy_s(pModeName, nBufferCharacters, L"Decompress"); break;
+        case MODE_VERIFY: bActive ? wcscpy_s(pModeName, nBufferCharacters, L"Verifying") : wcscpy_s(pModeName, nBufferCharacters, L"Verify"); break;
+        case MODE_CONVERT: bActive ? wcscpy_s(pModeName, nBufferCharacters, L"Converting") : wcscpy_s(pModeName, nBufferCharacters, L"Convert"); break;
+        case MODE_MAKE_APL: bActive ? wcscpy_s(pModeName, nBufferCharacters, L"Making APL's") : wcscpy_s(pModeName, nBufferCharacters, L"Make APL's"); break;
+        // all other conditions to prevent compiler warnings (4061, 4062, and Clang)
+        case MODE_CHECK: break; // not used
+        case MODE_COUNT: break; // not used
+    }
+
+}
+
 /**************************************************************************************************
-Simple progress callback (for legacy support)
+Simple progress callback
 **************************************************************************************************/
-class CAPEProgressCallbackLegacy : public IAPEProgressCallback
+class CAPEProgressCallbackSimple : public IAPEProgressCallback
 {
 public:
-    CAPEProgressCallbackLegacy(int * pProgress, APE_PROGRESS_CALLBACK ProgressCallback, int * pKillFlag)
+    CAPEProgressCallbackSimple(int * pProgress, APE_PROGRESS_CALLBACK ProgressCallback, int * pKillFlag)
     {
         m_pProgress = pProgress;
         m_ProgressCallback = ProgressCallback;
         m_pKillFlag = pKillFlag;
-        m_cType[0] = 0;
     }
 
     virtual void Progress(int nPercentageDone) APE_OVERRIDE
@@ -347,84 +368,83 @@ private:
     int * m_pProgress;
     APE_PROGRESS_CALLBACK m_ProgressCallback;
     int * m_pKillFlag;
-    str_ansi m_cType[8];
 };
 
 /**************************************************************************************************
 ANSI wrappers
 **************************************************************************************************/
 #ifdef APE_SUPPORT_COMPRESS
-int __stdcall CompressFile(const APE::str_ansi * pInputFilename, const APE::str_ansi * pOutputFilename, int nCompressionLevel, int * pPercentageDone, APE_PROGRESS_CALLBACK ProgressCallback, int * pKillFlag)
+int __stdcall CompressFile(const APE::str_ansi * pInputFilename, const APE::str_ansi * pOutputFilename, int nCompressionLevel, int * pPercentageDone, APE_PROGRESS_CALLBACK ProgressCallback, int * pKillFlag, int nThreads)
 {
     CSmartPtr<str_utfn> spInputFile(CAPECharacterHelper::GetUTF16FromANSI(pInputFilename), true);
     CSmartPtr<str_utfn> spOutputFile(CAPECharacterHelper::GetUTF16FromANSI(pOutputFilename), true);
-    return CompressFileW(spInputFile, spOutputFile, nCompressionLevel, pPercentageDone, ProgressCallback, pKillFlag);
+    return CompressFileW(spInputFile, spOutputFile, nCompressionLevel, pPercentageDone, ProgressCallback, pKillFlag, nThreads);
 }
 #endif
 
-int __stdcall DecompressFile(const APE::str_ansi * pInputFilename, const APE::str_ansi * pOutputFilename, int * pPercentageDone, APE_PROGRESS_CALLBACK ProgressCallback, int * pKillFlag)
+int __stdcall DecompressFile(const APE::str_ansi * pInputFilename, const APE::str_ansi * pOutputFilename, int * pPercentageDone, APE_PROGRESS_CALLBACK ProgressCallback, int * pKillFlag, int nThreads)
 {
     if (pOutputFilename == APE_NULL)
     {
         CSmartPtr<str_utfn> spInputFile(CAPECharacterHelper::GetUTF16FromANSI(pInputFilename), true);
-        return DecompressFileW(spInputFile, APE_NULL, pPercentageDone, ProgressCallback, pKillFlag);
+        return DecompressFileW(spInputFile, APE_NULL, pPercentageDone, ProgressCallback, pKillFlag, nThreads);
     }
     else
     {
         CSmartPtr<str_utfn> spInputFile(CAPECharacterHelper::GetUTF16FromANSI(pInputFilename), true);
         CSmartPtr<str_utfn> spOutputFile(CAPECharacterHelper::GetUTF16FromANSI(pOutputFilename), true);
-        return DecompressFileW(spInputFile, spOutputFile, pPercentageDone, ProgressCallback, pKillFlag);
+        return DecompressFileW(spInputFile, spOutputFile, pPercentageDone, ProgressCallback, pKillFlag, nThreads);
     }
 }
 
-int __stdcall ConvertFile(const APE::str_ansi * pInputFilename, const APE::str_ansi * pOutputFilename, int nCompressionLevel, int * pPercentageDone, APE_PROGRESS_CALLBACK ProgressCallback, int * pKillFlag)
+int __stdcall ConvertFile(const APE::str_ansi * pInputFilename, const APE::str_ansi * pOutputFilename, int nCompressionLevel, int * pPercentageDone, APE_PROGRESS_CALLBACK ProgressCallback, int * pKillFlag, int nThreads)
 {
     CSmartPtr<str_utfn> spInputFile(CAPECharacterHelper::GetUTF16FromANSI(pInputFilename), true);
     CSmartPtr<str_utfn> spOutputFile(CAPECharacterHelper::GetUTF16FromANSI(pOutputFilename), true);
-    return ConvertFileW(spInputFile, spOutputFile, nCompressionLevel, pPercentageDone, ProgressCallback, pKillFlag);
+    return ConvertFileW(spInputFile, spOutputFile, nCompressionLevel, pPercentageDone, ProgressCallback, pKillFlag, nThreads);
 }
 
-int __stdcall VerifyFile(const APE::str_ansi * pInputFilename, int * pPercentageDone, APE_PROGRESS_CALLBACK ProgressCallback, int * pKillFlag, bool bQuickVerifyIfPossible)
+int __stdcall VerifyFile(const APE::str_ansi * pInputFilename, int * pPercentageDone, APE_PROGRESS_CALLBACK ProgressCallback, int * pKillFlag, bool bQuickVerifyIfPossible, int nThreads)
 {
     CSmartPtr<str_utfn> spInputFile(CAPECharacterHelper::GetUTF16FromANSI(pInputFilename), true);
-    return VerifyFileW(spInputFile, pPercentageDone, ProgressCallback, pKillFlag, bQuickVerifyIfPossible);
+    return VerifyFileW(spInputFile, pPercentageDone, ProgressCallback, pKillFlag, bQuickVerifyIfPossible, nThreads);
 }
 
 /**************************************************************************************************
 Legacy callback wrappers
 **************************************************************************************************/
 #ifdef APE_SUPPORT_COMPRESS
-int __stdcall CompressFileW(const APE::str_utfn * pInputFilename, const APE::str_utfn * pOutputFilename, int nCompressionLevel, int * pPercentageDone, APE_PROGRESS_CALLBACK ProgressCallback, int * pKillFlag)
+int __stdcall CompressFileW(const APE::str_utfn * pInputFilename, const APE::str_utfn * pOutputFilename, int nCompressionLevel, int * pPercentageDone, APE_PROGRESS_CALLBACK ProgressCallback, int * pKillFlag, int nThreads)
 {
-    CAPEProgressCallbackLegacy ProgressCallbackLegacy(pPercentageDone, ProgressCallback, pKillFlag);
-    return CompressFileW2(pInputFilename, pOutputFilename, nCompressionLevel, &ProgressCallbackLegacy);
+    CAPEProgressCallbackSimple ProgressCallbackSimple(pPercentageDone, ProgressCallback, pKillFlag);
+    return CompressFileW2(pInputFilename, pOutputFilename, nCompressionLevel, &ProgressCallbackSimple, nThreads);
 }
 #endif
 
-int __stdcall VerifyFileW(const APE::str_utfn * pInputFilename, int * pPercentageDone, APE_PROGRESS_CALLBACK ProgressCallback, int * pKillFlag, bool bQuickVerifyIfPossible)
+int __stdcall VerifyFileW(const APE::str_utfn * pInputFilename, int * pPercentageDone, APE_PROGRESS_CALLBACK ProgressCallback, int * pKillFlag, bool bQuickVerifyIfPossible, int nThreads)
 {
-    CAPEProgressCallbackLegacy ProgressCallbackLegacy(pPercentageDone, ProgressCallback, pKillFlag);
-    return VerifyFileW2(pInputFilename, &ProgressCallbackLegacy, bQuickVerifyIfPossible);
+    CAPEProgressCallbackSimple ProgressCallbackSimple(pPercentageDone, ProgressCallback, pKillFlag);
+    return VerifyFileW2(pInputFilename, &ProgressCallbackSimple, bQuickVerifyIfPossible, nThreads);
 }
 
-int __stdcall DecompressFileW(const APE::str_utfn * pInputFilename, const APE::str_utfn * pOutputFilename, int * pPercentageDone, APE_PROGRESS_CALLBACK ProgressCallback, int * pKillFlag)
+int __stdcall DecompressFileW(const APE::str_utfn * pInputFilename, const APE::str_utfn * pOutputFilename, int * pPercentageDone, APE_PROGRESS_CALLBACK ProgressCallback, int * pKillFlag, int nThreads)
 {
-    CAPEProgressCallbackLegacy ProgressCallbackLegacy(pPercentageDone, ProgressCallback, pKillFlag);
-    const int nResult = DecompressFileW2(pInputFilename, pOutputFilename, &ProgressCallbackLegacy);
+    CAPEProgressCallbackSimple ProgressCallbackSimple(pPercentageDone, ProgressCallback, pKillFlag);
+    const int nResult = DecompressFileW2(pInputFilename, pOutputFilename, &ProgressCallbackSimple, nThreads);
     return nResult;
 }
 
-int __stdcall ConvertFileW(const APE::str_utfn * pInputFilename, const APE::str_utfn * pOutputFilename, int nCompressionLevel, int * pPercentageDone, APE_PROGRESS_CALLBACK ProgressCallback, int * pKillFlag)
+int __stdcall ConvertFileW(const APE::str_utfn * pInputFilename, const APE::str_utfn * pOutputFilename, int nCompressionLevel, int * pPercentageDone, APE_PROGRESS_CALLBACK ProgressCallback, int * pKillFlag, int nThreads)
 {
-    CAPEProgressCallbackLegacy ProgressCallbackLegacy(pPercentageDone, ProgressCallback, pKillFlag);
-    return ConvertFileW2(pInputFilename, pOutputFilename, nCompressionLevel, &ProgressCallbackLegacy);
+    CAPEProgressCallbackSimple ProgressCallbackSimple(pPercentageDone, ProgressCallback, pKillFlag);
+    return ConvertFileW2(pInputFilename, pOutputFilename, nCompressionLevel, &ProgressCallbackSimple, nThreads);
 }
 
 /**************************************************************************************************
 Compress file
 **************************************************************************************************/
 #ifdef APE_SUPPORT_COMPRESS
-int __stdcall CompressFileW2(const APE::str_utfn * pInputFilename, const APE::str_utfn * pOutputFilename, int nCompressionLevel, IAPEProgressCallback * pProgressCallback)
+int __stdcall CompressFileW2(const APE::str_utfn * pInputFilename, const APE::str_utfn * pOutputFilename, int nCompressionLevel, IAPEProgressCallback * pProgressCallback, int nThreads)
 {
     // declare the variables
     int nFunctionRetVal = ERROR_SUCCESS;
@@ -438,7 +458,7 @@ int __stdcall CompressFileW2(const APE::str_utfn * pInputFilename, const APE::st
         // create the input source
         int nResult = ERROR_UNDEFINED;
         int64 nAudioBlocks = 0; int64 nHeaderBytes = 0; int64 nTerminatingBytes = 0; int32 nFlags = 0;
-        CSmartPtr<CInputSource> spInputSource(CreateInputSource(pInputFilename, &WaveFormatEx, &nAudioBlocks,
+        CSmartPtr<CInputSource> spInputSource(CInputSource::CreateInputSource(pInputFilename, &WaveFormatEx, &nAudioBlocks,
             &nHeaderBytes, &nTerminatingBytes, &nFlags, &nResult));
 
         // check header and footer sizes right away (we also check the footer at the end, but that would require compressing the whole file then rejecting)
@@ -455,9 +475,12 @@ int __stdcall CompressFileW2(const APE::str_utfn * pInputFilename, const APE::st
         spAPECompress.Assign(CreateIAPECompress());
         if (spAPECompress == APE_NULL) throw static_cast<intn>(ERROR_UNDEFINED);
 
+        // set the threads
+        spAPECompress->SetNumberOfThreads(nThreads);
+
         // figure the audio bytes
         int64 nAudioBytes = static_cast<int64>(nAudioBlocks) * static_cast<int64>(WaveFormatEx.nBlockAlign);
-        if (spInputSource->GetUnknownLengthPipe())
+        if (spInputSource->GetUnknownLengthFile())
             nAudioBytes = MAX_AUDIO_BYTES_UNKNOWN;
         if ((nAudioBytes <= 0) && (nAudioBytes != MAX_AUDIO_BYTES_UNKNOWN))
             throw static_cast<intn>(ERROR_INPUT_FILE_TOO_SMALL);
@@ -465,7 +488,7 @@ int __stdcall CompressFileW2(const APE::str_utfn * pInputFilename, const APE::st
         // start the encoder
         if (nHeaderBytes > 0) spBuffer.Assign(new unsigned char[static_cast<uint32>(nHeaderBytes)], true);
         THROW_ON_ERROR(spInputSource->GetHeaderData(spBuffer.GetPtr()))
-        THROW_ON_ERROR(spAPECompress->Start(pOutputFilename, &WaveFormatEx, nAudioBytes, nCompressionLevel, spBuffer.GetPtr(), nHeaderBytes, nFlags))
+        THROW_ON_ERROR(spAPECompress->Start(pOutputFilename, &WaveFormatEx, spInputSource->GetFloat(), nAudioBytes, nCompressionLevel, spBuffer.GetPtr(), nHeaderBytes, nFlags))
         spBuffer.Delete();
 
         // set-up the progress
@@ -473,13 +496,13 @@ int __stdcall CompressFileW2(const APE::str_utfn * pInputFilename, const APE::st
 
         // master loop
         int64 nBytesLeft = nAudioBytes;
-        const bool bUnknownLengthPipe = spInputSource->GetUnknownLengthPipe();
-        while ((nBytesLeft > 0) || bUnknownLengthPipe)
+        const bool bUnknownLengthFile = spInputSource->GetUnknownLengthFile();
+        while ((nBytesLeft > 0) || bUnknownLengthFile)
         {
             // add data
             int64 nBytesAdded = 0;
             const int64 nRetVal = spAPECompress->AddDataFromInputSource(spInputSource.GetPtr(), nBytesLeft, &nBytesAdded);
-            if (bUnknownLengthPipe && (nRetVal == ERROR_IO_READ))
+            if (bUnknownLengthFile && (nRetVal == ERROR_IO_READ))
                 break; // this means we reached the end of the file
             else if (nRetVal != ERROR_SUCCESS)
                 throw(static_cast<intn>(nRetVal));
@@ -514,10 +537,6 @@ int __stdcall CompressFileW2(const APE::str_utfn * pInputFilename, const APE::st
         nFunctionRetVal = ERROR_UNDEFINED;
     }
 
-    // kill the compressor if we failed
-    if ((nFunctionRetVal != 0) && (spAPECompress != APE_NULL))
-        spAPECompress->Kill();
-
     // return
     return nFunctionRetVal;
 }
@@ -526,7 +545,7 @@ int __stdcall CompressFileW2(const APE::str_utfn * pInputFilename, const APE::st
 /**************************************************************************************************
 Verify file
 **************************************************************************************************/
-int __stdcall VerifyFileW2(const APE::str_utfn * pInputFilename, IAPEProgressCallback * pProgressCallback, bool bQuickVerifyIfPossible)
+int __stdcall VerifyFileW2(const APE::str_utfn * pInputFilename, IAPEProgressCallback * pProgressCallback, bool bQuickVerifyIfPossible, int nThreads)
 {
     // error check the function parameters
     if (pInputFilename == APE_NULL)
@@ -563,6 +582,9 @@ int __stdcall VerifyFileW2(const APE::str_utfn * pInputFilename, IAPEProgressCal
             // make sure the MD5 is valid
             if (pInfo->nMD5Invalid)
                 throw(static_cast<intn>(ERROR_UNSUPPORTED_FILE_VERSION));
+
+            // set the threads
+            spAPEDecompress->SetNumberOfThreads(nThreads);
         }
         catch (...)
         {
@@ -589,17 +611,17 @@ int __stdcall VerifyFileW2(const APE::str_utfn * pInputFilename, IAPEProgressCal
                 throw(static_cast<intn>(ERROR_UNSUPPORTED_FILE_VERSION));
 
             // read APE header
-            CSmartPtr<unsigned char> spAPEHeader(new unsigned char[pInfo->spAPEDescriptor->nHeaderBytes], true);
+            CSmartPtr<unsigned char> spAPEHeader(new unsigned char [pInfo->spAPEDescriptor->nHeaderBytes], true);
             pIO->Seek(static_cast<int64>(pInfo->nJunkHeaderBytes) + static_cast<int64>(pInfo->spAPEDescriptor->nDescriptorBytes), SeekFileBegin);
             pIO->Read(spAPEHeader, pInfo->spAPEDescriptor->nHeaderBytes, &nBytesRead);
 
             // read seek table
-            CSmartPtr<unsigned char> spSeekTable(new unsigned char[pInfo->spAPEDescriptor->nSeekTableBytes], true);
+            CSmartPtr<unsigned char> spSeekTable(new unsigned char [pInfo->spAPEDescriptor->nSeekTableBytes], true);
             ASSERT(pIO->GetPosition() == (static_cast<int64>(pInfo->nJunkHeaderBytes) + static_cast<int64>(pInfo->spAPEDescriptor->nDescriptorBytes) + static_cast<int64>(pInfo->spAPEDescriptor->nHeaderBytes)));
             pIO->Read(spSeekTable, pInfo->spAPEDescriptor->nSeekTableBytes, &nBytesRead);
 
             // read header data
-            CSmartPtr<unsigned char> spHeader(new unsigned char[pInfo->spAPEDescriptor->nHeaderDataBytes], true);
+            CSmartPtr<unsigned char> spHeader(new unsigned char [pInfo->spAPEDescriptor->nHeaderDataBytes], true);
             ASSERT(pIO->GetPosition() == (static_cast<int64>(pInfo->nJunkHeaderBytes) + static_cast<int64>(pInfo->spAPEDescriptor->nDescriptorBytes) + static_cast<int64>(pInfo->spAPEDescriptor->nHeaderBytes) + static_cast<int64>(pInfo->spAPEDescriptor->nSeekTableBytes)));
             pIO->Read(spHeader, static_cast<unsigned int>(pInfo->spAPEDescriptor->nHeaderDataBytes), &nBytesRead);
 
@@ -617,11 +639,11 @@ int __stdcall VerifyFileW2(const APE::str_utfn * pInputFilename, IAPEProgressCal
             CSmartPtr<CMACProgressHelper> spMACProgressHelper;
             spMACProgressHelper.Assign(new CMACProgressHelper(nBytesLeft, pProgressCallback));
 
-            CSmartPtr<unsigned char> spBuffer(new unsigned char[16384], true);
+            CSmartPtr<unsigned char> spBuffer(new unsigned char [16384], true);
             nBytesRead = 1;
             while ((nBytesLeft > 0) && (nBytesRead > 0))
             {
-                const unsigned int nBytesToRead = static_cast<unsigned int>(ape_min(16384, nBytesLeft));
+                const unsigned int nBytesToRead = static_cast<unsigned int>(APE_MIN(16384, nBytesLeft));
                 if (pIO->Read(spBuffer, nBytesToRead, &nBytesRead) != ERROR_SUCCESS)
                     throw(static_cast<intn>(ERROR_IO_READ));
 
@@ -646,8 +668,7 @@ int __stdcall VerifyFileW2(const APE::str_utfn * pInputFilename, IAPEProgressCal
             MD5Helper.GetResult(cResult);
 
             // compare to stored
-            if (memcmp(cResult, pInfo->spAPEDescriptor->cFileMD5, 16) != 0)
-                nFunctionRetVal = ERROR_INVALID_CHECKSUM;
+            nFunctionRetVal = static_cast<int>(spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_MD5_MATCHES, POINTER_TO_INT64(&cResult[0])));
 
             // update the progress to 100%
             spMACProgressHelper->UpdateProgressComplete();
@@ -666,7 +687,7 @@ int __stdcall VerifyFileW2(const APE::str_utfn * pInputFilename, IAPEProgressCal
     }
     else
     {
-        nResult = DecompressCore(pInputFilename, APE_NULL, UNMAC_DECODER_OUTPUT_NONE, -1, pProgressCallback, spAPEDecompress);
+        nResult = DecompressCore(pInputFilename, APE_NULL, UNMAC_DECODER_OUTPUT_NONE, -1, pProgressCallback, spAPEDecompress, nThreads);
     }
 
     return nResult;
@@ -675,26 +696,26 @@ int __stdcall VerifyFileW2(const APE::str_utfn * pInputFilename, IAPEProgressCal
 /**************************************************************************************************
 Decompress file
 **************************************************************************************************/
-int __stdcall DecompressFileW2(const APE::str_utfn * pInputFilename, const APE::str_utfn * pOutputFilename, IAPEProgressCallback * pProgressCallback)
+int __stdcall DecompressFileW2(const APE::str_utfn * pInputFilename, const APE::str_utfn * pOutputFilename, IAPEProgressCallback * pProgressCallback, int nThreads)
 {
     if (pOutputFilename == APE_NULL)
         return VerifyFileW2(pInputFilename, pProgressCallback);
     else
-        return DecompressCore(pInputFilename, pOutputFilename, UNMAC_DECODER_OUTPUT_WAV, -1, pProgressCallback, APE_NULL);
+        return DecompressCore(pInputFilename, pOutputFilename, UNMAC_DECODER_OUTPUT_WAV, -1, pProgressCallback, APE_NULL, nThreads);
 }
 
 /**************************************************************************************************
 Convert file
 **************************************************************************************************/
-int __stdcall ConvertFileW2(const APE::str_utfn * pInputFilename, const APE::str_utfn * pOutputFilename, int nCompressionLevel, IAPEProgressCallback * pProgressCallback)
+int __stdcall ConvertFileW2(const APE::str_utfn * pInputFilename, const APE::str_utfn * pOutputFilename, int nCompressionLevel, IAPEProgressCallback * pProgressCallback, int nThreads)
 {
-    return DecompressCore(pInputFilename, pOutputFilename, UNMAC_DECODER_OUTPUT_APE, nCompressionLevel, pProgressCallback, APE_NULL);
+    return DecompressCore(pInputFilename, pOutputFilename, UNMAC_DECODER_OUTPUT_APE, nCompressionLevel, pProgressCallback, APE_NULL, nThreads);
 }
 
 /**************************************************************************************************
 Decompress a file using the specified output method
 **************************************************************************************************/
-int DecompressCore(const APE::str_utfn * pInputFilename, const APE::str_utfn * pOutputFilename, int nOutputMode, int nCompressionLevel, IAPEProgressCallback * pProgressCallback, IAPEDecompress * pDecompress)
+int DecompressCore(const APE::str_utfn * pInputFilename, const APE::str_utfn * pOutputFilename, int nOutputMode, int nCompressionLevel, IAPEProgressCallback * pProgressCallback, IAPEDecompress * pDecompress, int nThreads)
 {
     // error check the function parameters
     if (pInputFilename == APE_NULL)
@@ -724,11 +745,14 @@ int DecompressCore(const APE::str_utfn * pInputFilename, const APE::str_utfn * p
         }
         if (spAPEDecompress == APE_NULL || nFunctionRetVal != ERROR_SUCCESS) throw(static_cast<intn>(nFunctionRetVal));
 
+        // set the threads
+        spAPEDecompress->SetNumberOfThreads(nThreads);
+
         // get the input format
         THROW_ON_ERROR(spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_WAVEFORMATEX, POINTER_TO_INT64(&wfeInput)))
 
         // allocate space for the header
-        spTempBuffer.Assign(new unsigned char[static_cast<size_t>(spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_WAV_HEADER_BYTES))], true);
+        spTempBuffer.Assign(new unsigned char [static_cast<size_t>(spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_WAV_HEADER_BYTES))], true);
         if (spTempBuffer == APE_NULL) throw(static_cast<intn>(ERROR_INSUFFICIENT_MEMORY));
 
         // get the header
@@ -749,7 +773,7 @@ int DecompressCore(const APE::str_utfn * pInputFilename, const APE::str_utfn * p
         {
             // quit if there is nothing to do
             // no longer check when processing an APL since converting an APL to APE should work no matter what
-            if ((spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_FILE_VERSION) == MAC_FILE_VERSION_NUMBER) &&
+            if ((spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_FILE_VERSION) == APE_FILE_VERSION_NUMBER) &&
                 (spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_COMPRESSION_LEVEL) == nCompressionLevel) &&
                 (spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_APL) == false))
             {
@@ -766,13 +790,14 @@ int DecompressCore(const APE::str_utfn * pInputFilename, const APE::str_utfn * p
 
             // create and start the compressor
             spAPECompress.Assign(CreateIAPECompress());
-            THROW_ON_ERROR(spAPECompress->Start(pOutputFilename, &wfeInput, (spAPEDecompress->GetInfo(IAPEDecompress::APE_DECOMPRESS_TOTAL_BLOCKS) * spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_BLOCK_ALIGN)),
+            THROW_ON_ERROR(spAPECompress->Start(pOutputFilename, &wfeInput, spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_FORMAT_FLAGS) & APE_FORMAT_FLAG_FLOATING_POINT,
+                (spAPEDecompress->GetInfo(IAPEDecompress::APE_DECOMPRESS_TOTAL_BLOCKS) * spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_BLOCK_ALIGN)),
                 nCompressionLevel, spTempBuffer, spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_WAV_HEADER_BYTES), nFlags))
         }
 #endif
 
         // allocate space for decompression
-        spTempBuffer.Assign(new unsigned char[static_cast<size_t>(spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_BLOCK_ALIGN)) * BLOCKS_PER_DECODE], true);
+        spTempBuffer.Assign(new unsigned char [static_cast<size_t>(spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_BLOCK_ALIGN)) * BLOCKS_PER_DECODE], true);
         if (spTempBuffer == APE_NULL) throw(static_cast<intn>(ERROR_INSUFFICIENT_MEMORY));
 
         int64 nBlocksLeft = static_cast<intn>(spAPEDecompress->GetInfo(IAPEDecompress::APE_DECOMPRESS_TOTAL_BLOCKS));
@@ -780,15 +805,12 @@ int DecompressCore(const APE::str_utfn * pInputFilename, const APE::str_utfn * p
         // create the progress helper
         spMACProgressHelper.Assign(new CMACProgressHelper(nBlocksLeft / BLOCKS_PER_DECODE, pProgressCallback));
 
+        // processing flags
+        IAPEDecompress::APE_GET_DATA_PROCESSING Processing = { (nOutputMode != UNMAC_DECODER_OUTPUT_APE), (nOutputMode != UNMAC_DECODER_OUTPUT_APE), (nOutputMode != UNMAC_DECODER_OUTPUT_APE) };
+
         // main decoding loop
         while (nBlocksLeft > 0)
         {
-            // processing flags
-            IAPEDecompress::APE_GET_DATA_PROCESSING Processing;
-            Processing.bApplyFloatProcessing = (nOutputMode != UNMAC_DECODER_OUTPUT_APE);
-            Processing.bApplySigned8BitProcessing = (nOutputMode != UNMAC_DECODER_OUTPUT_APE);
-            Processing.bApplyBigEndianProcessing = (nOutputMode != UNMAC_DECODER_OUTPUT_APE);
-
             // decode data
             int64 nBlocksDecoded = -1;
             const int nResult = spAPEDecompress->GetData(spTempBuffer, BLOCKS_PER_DECODE, &nBlocksDecoded, &Processing);
@@ -798,6 +820,10 @@ int DecompressCore(const APE::str_utfn * pInputFilename, const APE::str_utfn * p
             // handle the output
             if (nOutputMode == UNMAC_DECODER_OUTPUT_WAV)
             {
+#if APE_BYTE_ORDER == APE_BIG_ENDIAN
+                if (wfeInput.wBitsPerSample >= 16)
+                    SwitchBufferBytes(spTempBuffer, wfeInput.wBitsPerSample / 8, nBlocksDecoded * wfeInput.nChannels);
+#endif
                 const unsigned int nBytesToWrite = static_cast<unsigned int>(nBlocksDecoded * spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_BLOCK_ALIGN));
                 unsigned int nBytesWritten = 0;
                 const int nWriteResult = spioOutput->Write(spTempBuffer, nBytesToWrite, &nBytesWritten);
@@ -824,7 +850,7 @@ int DecompressCore(const APE::str_utfn * pInputFilename, const APE::str_utfn * p
             // write any terminating WAV data
             if (spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_WAV_TERMINATING_BYTES) > 0)
             {
-                spTempBuffer.Assign(new unsigned char[static_cast<size_t>(spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_WAV_TERMINATING_BYTES))], true);
+                spTempBuffer.Assign(new unsigned char [static_cast<size_t>(spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_WAV_TERMINATING_BYTES))], true);
                 if (spTempBuffer == APE_NULL) throw(static_cast<intn>(ERROR_INSUFFICIENT_MEMORY));
                 THROW_ON_ERROR(spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_WAV_TERMINATING_DATA, POINTER_TO_INT64(spTempBuffer.GetPtr()), spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_WAV_TERMINATING_BYTES)))
 
@@ -846,7 +872,7 @@ int DecompressCore(const APE::str_utfn * pInputFilename, const APE::str_utfn * p
 
             if (nTerminatingBytes > 0)
             {
-                spTempBuffer.Assign(new unsigned char[static_cast<size_t>(nTerminatingBytes)], true);
+                spTempBuffer.Assign(new unsigned char [static_cast<size_t>(nTerminatingBytes)], true);
                 if (spTempBuffer == APE_NULL) throw(static_cast<intn>(ERROR_INSUFFICIENT_MEMORY));
 
                 THROW_ON_ERROR(spAPEDecompress->GetInfo(IAPEDecompress::APE_INFO_WAV_TERMINATING_DATA, POINTER_TO_INT64(spTempBuffer.GetPtr()), nTerminatingBytes))
