@@ -19,23 +19,23 @@ template <class INTTYPE, class DATATYPE> CPredictorCompressNormal<INTTYPE, DATAT
     APE_CLEAR(m_aryM);
     m_nCurrentIndex = 0;
 
-    if (nCompressionLevel == MAC_COMPRESSION_LEVEL_FAST)
+    if (nCompressionLevel == APE_COMPRESSION_LEVEL_FAST)
     {
     }
-    else if (nCompressionLevel == MAC_COMPRESSION_LEVEL_NORMAL)
+    else if (nCompressionLevel == APE_COMPRESSION_LEVEL_NORMAL)
     {
         m_spNNFilter.Assign(new CNNFilter<INTTYPE, DATATYPE>(16, 11));
     }
-    else if (nCompressionLevel == MAC_COMPRESSION_LEVEL_HIGH)
+    else if (nCompressionLevel == APE_COMPRESSION_LEVEL_HIGH)
     {
         m_spNNFilter.Assign(new CNNFilter<INTTYPE, DATATYPE>(64, 11));
     }
-    else if (nCompressionLevel == MAC_COMPRESSION_LEVEL_EXTRA_HIGH)
+    else if (nCompressionLevel == APE_COMPRESSION_LEVEL_EXTRA_HIGH)
     {
         m_spNNFilter.Assign(new CNNFilter<INTTYPE, DATATYPE>(256, 13));
         m_spNNFilter1.Assign(new CNNFilter<INTTYPE, DATATYPE>(32, 10));
     }
-    else if (nCompressionLevel == MAC_COMPRESSION_LEVEL_INSANE)
+    else if (nCompressionLevel == APE_COMPRESSION_LEVEL_INSANE)
     {
         m_spNNFilter.Assign(new CNNFilter<INTTYPE, DATATYPE>(1024 + 256, 15));
         m_spNNFilter1.Assign(new CNNFilter<INTTYPE, DATATYPE>(256, 13));
@@ -115,21 +115,13 @@ template <class INTTYPE, class DATATYPE> int64 CPredictorCompressNormal<INTTYPE,
     }
 
     // adapt
-    m_rbAdapt[0] = (m_rbPrediction[-1]) ? ((m_rbPrediction[-1] >> 30) & 2) - 1 : 0;
+    m_rbAdapt[ 0] = (m_rbPrediction[-1]) ? ((m_rbPrediction[-1] >> 30) & 2) - 1 : 0;
     m_rbAdapt[-1] = (m_rbPrediction[-2]) ? ((m_rbPrediction[-2] >> 30) & 2) - 1 : 0;
     m_rbAdapt[-4] = (m_rbPrediction[-5]) ? ((m_rbPrediction[-5] >> 30) & 2) - 1 : 0;
     m_rbAdapt[-5] = (m_rbPrediction[-6]) ? ((m_rbPrediction[-6] >> 30) & 2) - 1 : 0;
 
-    if (nOutput > 0)
-    {
-        INTTYPE * pM = &paryM[-8]; INTTYPE * pAdapt = &m_rbAdapt[-8];
-        EXPAND_9_TIMES(*pM++ -= *pAdapt++;)
-    }
-    else if (nOutput < 0)
-    {
-        INTTYPE * pM = &paryM[-8]; INTTYPE * pAdapt = &m_rbAdapt[-8];
-        EXPAND_9_TIMES(*pM++ += *pAdapt++;)
-    }
+    INTTYPE * pM = &paryM[-8]; INTTYPE * pAdapt = &m_rbAdapt[-8];
+    EXPAND_9_TIMES(*pM++ += *pAdapt++ * ((nOutput < 0) - (nOutput > 0));)
 
     // stage 3: NNFilters
     if (m_spNNFilter)
@@ -161,25 +153,25 @@ CPredictorDecompressNormal3930to3950::CPredictorDecompressNormal3930to3950(int n
 {
     // initialize (to avoid warnings)
     APE_CLEAR(m_aryM);
-    m_pInputBuffer = NULL;
+    m_pInputBuffer = APE_NULL;
     m_nLastValue = 0;
     m_nCurrentIndex = 0;
 
     m_spBuffer.Assign(new int [HISTORY_ELEMENTS + WINDOW_BLOCKS], true);
 
-    if (nCompressionLevel == MAC_COMPRESSION_LEVEL_FAST)
+    if (nCompressionLevel == APE_COMPRESSION_LEVEL_FAST)
     {
         // no filters
     }
-    else if (nCompressionLevel == MAC_COMPRESSION_LEVEL_NORMAL)
+    else if (nCompressionLevel == APE_COMPRESSION_LEVEL_NORMAL)
     {
         m_spNNFilter.Assign(new CNNFilter<int, short>(16, 11, nVersion));
     }
-    else if (nCompressionLevel == MAC_COMPRESSION_LEVEL_HIGH)
+    else if (nCompressionLevel == APE_COMPRESSION_LEVEL_HIGH)
     {
         m_spNNFilter.Assign(new CNNFilter<int, short>(64, 11, nVersion));
     }
-    else if (nCompressionLevel == MAC_COMPRESSION_LEVEL_EXTRA_HIGH)
+    else if (nCompressionLevel == APE_COMPRESSION_LEVEL_EXTRA_HIGH)
     {
         m_spNNFilter.Assign(new CNNFilter<int, short>(256, 13, nVersion));
         m_spNNFilter1.Assign(new CNNFilter<int, short>(32, 10, nVersion));
@@ -202,8 +194,8 @@ int CPredictorDecompressNormal3930to3950::Flush()
     if (m_spNNFilter) m_spNNFilter->Flush();
     if (m_spNNFilter1) m_spNNFilter1->Flush();
 
-    ZeroMemory(m_spBuffer, (HISTORY_ELEMENTS + 1) * sizeof(int));
-    ZeroMemory(&m_aryM[0], M_COUNT * sizeof(int));
+    ZeroMemory(m_spBuffer, (HISTORY_ELEMENTS + 1) * sizeof(m_spBuffer[0]));
+    ZeroMemory(&m_aryM[0], M_COUNT * sizeof(m_aryM[0]));
 
     m_aryM[0] = 360;
     m_aryM[1] = 317;
@@ -218,24 +210,24 @@ int CPredictorDecompressNormal3930to3950::Flush()
     return ERROR_SUCCESS;
 }
 
-int CPredictorDecompressNormal3930to3950::DecompressValue(int64 _nInput, int64)
+int CPredictorDecompressNormal3930to3950::DecompressValue(int64 nInput, int64)
 {
     if (m_nCurrentIndex == WINDOW_BLOCKS)
     {
         // copy forward and adjust pointers
-        memcpy(&m_spBuffer[0], &m_spBuffer[WINDOW_BLOCKS], HISTORY_ELEMENTS * sizeof(int64));
+        memmove(&m_spBuffer[0], &m_spBuffer[WINDOW_BLOCKS], HISTORY_ELEMENTS * sizeof(m_spBuffer[0]));
         m_pInputBuffer = &m_spBuffer[HISTORY_ELEMENTS];
 
         m_nCurrentIndex = 0;
     }
 
-    int nInput = static_cast<int>(_nInput);
+    int nInput32 = static_cast<int>(nInput);
 
     // stage 2: NNFilter
     if (m_spNNFilter1)
-        nInput = m_spNNFilter1->Decompress(nInput);
+        nInput32 = m_spNNFilter1->Decompress(nInput32);
     if (m_spNNFilter)
-        nInput = m_spNNFilter->Decompress(nInput);
+        nInput32 = m_spNNFilter->Decompress(nInput32);
 
     // stage 1: multiple predictors (order 2 and offset 1)
     const int p1 = m_pInputBuffer[-1];
@@ -243,22 +235,12 @@ int CPredictorDecompressNormal3930to3950::DecompressValue(int64 _nInput, int64)
     const int p3 = m_pInputBuffer[-2] - m_pInputBuffer[-3];
     const int p4 = m_pInputBuffer[-3] - m_pInputBuffer[-4];
 
-    m_pInputBuffer[0] = nInput + (((p1 * m_aryM[0]) + (p2 * m_aryM[1]) + (p3 * m_aryM[2]) + (p4 * m_aryM[3])) >> 9);
+    m_pInputBuffer[0] = nInput32 + (((p1 * m_aryM[0]) + (p2 * m_aryM[1]) + (p3 * m_aryM[2]) + (p4 * m_aryM[3])) >> 9);
 
-    if (nInput > 0)
-    {
-        m_aryM[0] -= ((p1 >> 30) & 2) - 1;
-        m_aryM[1] -= ((p2 >> 30) & 2) - 1;
-        m_aryM[2] -= ((p3 >> 30) & 2) - 1;
-        m_aryM[3] -= ((p4 >> 30) & 2) - 1;
-    }
-    else if (nInput < 0)
-    {
-        m_aryM[0] += ((p1 >> 30) & 2) - 1;
-        m_aryM[1] += ((p2 >> 30) & 2) - 1;
-        m_aryM[2] += ((p3 >> 30) & 2) - 1;
-        m_aryM[3] += ((p4 >> 30) & 2) - 1;
-    }
+    m_aryM[0] += (((p1 >> 30) & 2) - 1) * ((nInput32 < 0) - (nInput32 > 0));
+    m_aryM[1] += (((p2 >> 30) & 2) - 1) * ((nInput32 < 0) - (nInput32 > 0));
+    m_aryM[2] += (((p3 >> 30) & 2) - 1) * ((nInput32 < 0) - (nInput32 > 0));
+    m_aryM[3] += (((p4 >> 30) & 2) - 1) * ((nInput32 < 0) - (nInput32 > 0));
 
     const int nResult = m_pInputBuffer[0] + ((m_nLastValue * 31) >> 5);
     m_nLastValue = nResult;
@@ -285,23 +267,23 @@ template <class INTTYPE, class DATATYPE> CPredictorDecompress3950toCurrent<INTTY
     APE_CLEAR(m_aryMA);
     APE_CLEAR(m_aryMB);
 
-    if (nCompressionLevel == MAC_COMPRESSION_LEVEL_FAST)
+    if (nCompressionLevel == APE_COMPRESSION_LEVEL_FAST)
     {
     }
-    else if (nCompressionLevel == MAC_COMPRESSION_LEVEL_NORMAL)
+    else if (nCompressionLevel == APE_COMPRESSION_LEVEL_NORMAL)
     {
         m_spNNFilter.Assign(new CNNFilter<INTTYPE, DATATYPE>(16, 11, nVersion));
     }
-    else if (nCompressionLevel == MAC_COMPRESSION_LEVEL_HIGH)
+    else if (nCompressionLevel == APE_COMPRESSION_LEVEL_HIGH)
     {
         m_spNNFilter.Assign(new CNNFilter<INTTYPE, DATATYPE>(64, 11, nVersion));
     }
-    else if (nCompressionLevel == MAC_COMPRESSION_LEVEL_EXTRA_HIGH)
+    else if (nCompressionLevel == APE_COMPRESSION_LEVEL_EXTRA_HIGH)
     {
         m_spNNFilter.Assign(new CNNFilter<INTTYPE, DATATYPE>(256, 13, nVersion));
         m_spNNFilter1.Assign(new CNNFilter<INTTYPE, DATATYPE>(32, 10, nVersion));
     }
-    else if (nCompressionLevel == MAC_COMPRESSION_LEVEL_INSANE)
+    else if (nCompressionLevel == APE_COMPRESSION_LEVEL_INSANE)
     {
         m_spNNFilter.Assign(new CNNFilter<INTTYPE, DATATYPE>(1024 + 256, 15, nVersion));
         m_spNNFilter1.Assign(new CNNFilter<INTTYPE, DATATYPE>(256, 13, nVersion));
@@ -406,38 +388,22 @@ template <class INTTYPE, class DATATYPE> int CPredictorDecompress3950toCurrent<I
             nCurrentA = nA + static_cast<INTTYPE>((static_cast<int>(nPredictionA) + (static_cast<int>(nPredictionB) >> 1)) >> 10);
     }
 
-    m_rbAdaptA[0] = (m_rbPredictionA[0]) ? ((m_rbPredictionA[0] >> 30) & 2) - 1 : 0;
+    m_rbAdaptA[ 0] = (m_rbPredictionA[ 0]) ? ((m_rbPredictionA[ 0] >> 30) & 2) - 1 : 0;
     m_rbAdaptA[-1] = (m_rbPredictionA[-1]) ? ((m_rbPredictionA[-1] >> 30) & 2) - 1 : 0;
 
-    m_rbAdaptB[0] = (m_rbPredictionB[0]) ? ((m_rbPredictionB[0] >> 30) & 2) - 1 : 0;
+    m_rbAdaptB[ 0] = (m_rbPredictionB[ 0]) ? ((m_rbPredictionB[ 0] >> 30) & 2) - 1 : 0;
     m_rbAdaptB[-1] = (m_rbPredictionB[-1]) ? ((m_rbPredictionB[-1] >> 30) & 2) - 1 : 0;
 
-    if (nA > 0)
-    {
-        m_aryMA[0] -= m_rbAdaptA[0];
-        m_aryMA[1] -= m_rbAdaptA[-1];
-        m_aryMA[2] -= m_rbAdaptA[-2];
-        m_aryMA[3] -= m_rbAdaptA[-3];
+    m_aryMA[0] += m_rbAdaptA[ 0] * ((nA < 0) - (nA > 0));
+    m_aryMA[1] += m_rbAdaptA[-1] * ((nA < 0) - (nA > 0));
+    m_aryMA[2] += m_rbAdaptA[-2] * ((nA < 0) - (nA > 0));
+    m_aryMA[3] += m_rbAdaptA[-3] * ((nA < 0) - (nA > 0));
 
-        m_aryMB[0] -= m_rbAdaptB[0];
-        m_aryMB[1] -= m_rbAdaptB[-1];
-        m_aryMB[2] -= m_rbAdaptB[-2];
-        m_aryMB[3] -= m_rbAdaptB[-3];
-        m_aryMB[4] -= m_rbAdaptB[-4];
-    }
-    else if (nA < 0)
-    {
-        m_aryMA[0] += m_rbAdaptA[0];
-        m_aryMA[1] += m_rbAdaptA[-1];
-        m_aryMA[2] += m_rbAdaptA[-2];
-        m_aryMA[3] += m_rbAdaptA[-3];
-
-        m_aryMB[0] += m_rbAdaptB[0];
-        m_aryMB[1] += m_rbAdaptB[-1];
-        m_aryMB[2] += m_rbAdaptB[-2];
-        m_aryMB[3] += m_rbAdaptB[-3];
-        m_aryMB[4] += m_rbAdaptB[-4];
-    }
+    m_aryMB[0] += m_rbAdaptB[ 0] * ((nA < 0) - (nA > 0));
+    m_aryMB[1] += m_rbAdaptB[-1] * ((nA < 0) - (nA > 0));
+    m_aryMB[2] += m_rbAdaptB[-2] * ((nA < 0) - (nA > 0));
+    m_aryMB[3] += m_rbAdaptB[-3] * ((nA < 0) - (nA > 0));
+    m_aryMB[4] += m_rbAdaptB[-4] * ((nA < 0) - (nA > 0));
 
     const int nResult = m_Stage1FilterA.Decompress(nCurrentA);
     m_nLastValueA = nCurrentA;
