@@ -17,7 +17,6 @@ Tasks:
 2) convert L,R to X,Y
 3) calculate the CRC
 4) do simple analysis
-5) check for the peak value
 **************************************************************************************************/
 
 class CIO;
@@ -26,7 +25,7 @@ class IPredictorDecompress;
 class CPrepare
 {
 public:
-    int Prepare(const unsigned char * pRawData, int nBytes, const WAVEFORMATEX * pWaveFormatEx, int * pOutput, int nFrameBlocks, unsigned int * pCRC, int * pSpecialCodes, int * pPeakLevel);
+    int Prepare(const unsigned char * pRawData, int nBytes, const WAVEFORMATEX * pWaveFormatEx, int * pOutput, int nFrameBlocks, unsigned int * pCRC, int * pSpecialCodes);
     void Unprepare(int * paryValues, const WAVEFORMATEX * pWaveFormatEx, unsigned char * pOutput);
 #ifdef APE_BACKWARDS_COMPATIBILITY
     int UnprepareOld(int * pInputX, int * pInputY, int nBlocks, const WAVEFORMATEX * pWaveFormatEx, unsigned char * pRawData, unsigned int * pCRC, int nFileVersion);
