@@ -5,14 +5,15 @@
 namespace APE
 {
 
-#pragma pack(push, 1)
-
 /**************************************************************************************************
 CInputSource - base input format class (allows multiple format support)
 **************************************************************************************************/
 class CInputSource
 {
 public:
+    // input source creation
+    static CInputSource * CreateInputSource(const wchar_t * pSourceName, WAVEFORMATEX * pwfeSource, int64 * pTotalBlocks, int64 * pHeaderBytes, int64 * pTerminatingBytes, int32 * pFlags, int * pErrorCode = APE_NULL);
+
     // construction / destruction
     virtual ~CInputSource() { }
 
@@ -24,14 +25,14 @@ public:
     virtual int GetTerminatingData(unsigned char * pBuffer) = 0;
 
     // get other properties
-    virtual bool GetUnknownLengthPipe() { return false; }
+    virtual bool GetUnknownLengthFile() { return false; }
+    virtual bool GetFloat() { return false; }
 
 protected:
     // get header / terminating data
     int GetHeaderDataHelper(bool bIsValid, unsigned char * pBuffer, uint32 nHeaderBytes, CIO * pIO);
     int GetTerminatingDataHelper(bool bIsValid, unsigned char * pBuffer, uint32 nTerminatingBytes, CIO * pIO);
     void Convert8BitSignedToUnsigned(unsigned char * pBuffer, int nChannels, int nBlocks);
-    void FlipEndian(unsigned char * pBuffer, int nBitsPerSample, int nChannels, int nBlocks);
 };
 
 /**************************************************************************************************
@@ -40,9 +41,12 @@ CWAVInputSource - wraps working with WAV files
 class CWAVInputSource : public CInputSource
 {
 public:
+    // test header
+    static bool GetHeaderMatches(BYTE aryHeader[64]);
+
     // construction / destruction
-    CWAVInputSource(const wchar_t * pSourceName, WAVEFORMATEX * pwfeSource, int64 * pTotalBlocks, int64 * pHeaderBytes, int64 * pTerminatingBytes, int * pErrorCode = APE_NULL);
-    ~CWAVInputSource();
+    CWAVInputSource(CIO * pIO, WAVEFORMATEX * pwfeSource, int64 * pTotalBlocks, int64 * pHeaderBytes, int64 * pTerminatingBytes, int * pErrorCode = APE_NULL);
+    ~CWAVInputSource() APE_OVERRIDE;
 
     // get data
     int GetData(unsigned char * pBuffer, int nBlocks, int * pBlocksRetrieved) APE_OVERRIDE;
@@ -52,7 +56,8 @@ public:
     int GetTerminatingData(unsigned char * pBuffer) APE_OVERRIDE;
 
     // get other properties
-    bool GetUnknownLengthPipe() APE_OVERRIDE { return m_bUnknownLengthPipe; }
+    bool GetUnknownLengthFile() APE_OVERRIDE { return m_bUnknownLengthFile; }
+    bool GetFloat() APE_OVERRIDE { return m_bFloat; }
 
 private:
     int AnalyzeSource();
@@ -62,10 +67,10 @@ private:
     uint32 m_nTerminatingBytes;
     int64 m_nDataBytes;
     int64 m_nFileBytes;
-    CSmartPtr<char> m_spFullHeader;
     WAVEFORMATEX m_wfeSource;
     bool m_bIsValid;
-    bool m_bUnknownLengthPipe;
+    bool m_bUnknownLengthFile;
+    bool m_bFloat;
 };
 
 /**************************************************************************************************
@@ -74,9 +79,12 @@ CAIFFInputSource - wraps working with AIFF files
 class CAIFFInputSource : public CInputSource
 {
 public:
+    // test header
+    static bool GetHeaderMatches(BYTE aryHeader[64]);
+
     // construction / destruction
-    CAIFFInputSource(const wchar_t * pSourceName, WAVEFORMATEX * pwfeSource, int64 * pTotalBlocks, int64 * pHeaderBytes, int64 * pTerminatingBytes, int * pErrorCode = APE_NULL);
-    ~CAIFFInputSource();
+    CAIFFInputSource(CIO * pIO, WAVEFORMATEX * pwfeSource, int64 * pTotalBlocks, int64 * pHeaderBytes, int64 * pTerminatingBytes, int * pErrorCode = APE_NULL);
+    ~CAIFFInputSource() APE_OVERRIDE;
 
     // get data
     int GetData(unsigned char * pBuffer, int nBlocks, int * pBlocksRetrieved) APE_OVERRIDE;
@@ -86,7 +94,10 @@ public:
     int GetTerminatingData(unsigned char * pBuffer) APE_OVERRIDE;
 
     // endian
-    bool GetIsBigEndian();
+    bool GetIsBigEndian() const;
+
+    // get other properties
+    bool GetFloat() APE_OVERRIDE { return m_bFloat; }
 
 private:
     int AnalyzeSource();
@@ -101,6 +112,7 @@ private:
     WAVEFORMATEX m_wfeSource;
     bool m_bIsValid;
     bool m_bLittleEndian;
+    bool m_bFloat;
 };
 
 /**************************************************************************************************
@@ -125,9 +137,12 @@ struct WAVFormatChunkData
 class CW64InputSource : public CInputSource
 {
 public:
+    // test header
+    static bool GetHeaderMatches(BYTE aryHeader[64]);
+
     // construction / destruction
-    CW64InputSource(const wchar_t * pSourceName, WAVEFORMATEX * pwfeSource, int64 * pTotalBlocks, int64 * pHeaderBytes, int64 * pTerminatingBytes, int * pErrorCode = APE_NULL);
-    ~CW64InputSource();
+    CW64InputSource(CIO * pIO, WAVEFORMATEX * pwfeSource, int64 * pTotalBlocks, int64 * pHeaderBytes, int64 * pTerminatingBytes, int * pErrorCode = APE_NULL);
+    ~CW64InputSource() APE_OVERRIDE;
 
     // get data
     int GetData(unsigned char * pBuffer, int nBlocks, int * pBlocksRetrieved) APE_OVERRIDE;
@@ -136,6 +151,9 @@ public:
     int GetHeaderData(unsigned char * pBuffer) APE_OVERRIDE;
     int GetTerminatingData(unsigned char * pBuffer) APE_OVERRIDE;
 
+    // get other properties
+    bool GetFloat() APE_OVERRIDE { return m_bFloat; }
+
 private:
     int AnalyzeSource();
     int64 Align(int64 nValue, int nAlignment);
@@ -147,6 +165,7 @@ private:
     int64 m_nFileBytes;
     WAVEFORMATEX m_wfeSource;
     bool m_bIsValid;
+    bool m_bFloat;
 };
 
 /**************************************************************************************************
@@ -155,9 +174,12 @@ CSNDInputSource - wraps working with SND files
 class CSNDInputSource : public CInputSource
 {
 public:
+    // test header
+    static bool GetHeaderMatches(BYTE aryHeader[64]);
+
     // construction / destruction
-    CSNDInputSource(const wchar_t * pSourceName, WAVEFORMATEX * pwfeSource, int64 * pTotalBlocks, int64 * pHeaderBytes, int64 * pTerminatingBytes, int * pErrorCode = APE_NULL, int32 * pFlags = APE_NULL);
-    ~CSNDInputSource();
+    CSNDInputSource(CIO * pIO, WAVEFORMATEX * pwfeSource, int64 * pTotalBlocks, int64 * pHeaderBytes, int64 * pTerminatingBytes, int * pErrorCode = APE_NULL, int32 * pFlags = APE_NULL);
+    ~CSNDInputSource() APE_OVERRIDE;
 
     // get data
     int GetData(unsigned char * pBuffer, int nBlocks, int * pBlocksRetrieved) APE_OVERRIDE;
@@ -166,9 +188,11 @@ public:
     int GetHeaderData(unsigned char * pBuffer) APE_OVERRIDE;
     int GetTerminatingData(unsigned char * pBuffer) APE_OVERRIDE;
 
+    // get other properties
+    bool GetFloat() APE_OVERRIDE { return (m_wfeSource.wFormatTag == WAVE_FORMAT_IEEE_FLOAT); }
+
 private:
     int AnalyzeSource(int32 * pFlags);
-    uint32 FlipByteOrder32(uint32 nValue);
 
     CSmartPtr<CIO> m_spIO;
     uint32 m_nHeaderBytes;
@@ -186,9 +210,12 @@ CCAFInputSource - wraps working with CAF files
 class CCAFInputSource : public CInputSource
 {
 public:
+    // test header
+    static bool GetHeaderMatches(BYTE aryHeader[64]);
+
     // construction / destruction
-    CCAFInputSource(const wchar_t * pSourceName, WAVEFORMATEX * pwfeSource, int64 * pTotalBlocks, int64 * pHeaderBytes, int64 * pTerminatingBytes, int * pErrorCode = APE_NULL);
-    ~CCAFInputSource();
+    CCAFInputSource(CIO * pIO, WAVEFORMATEX * pwfeSource, int64 * pTotalBlocks, int64 * pHeaderBytes, int64 * pTerminatingBytes, int * pErrorCode = APE_NULL);
+    ~CCAFInputSource() APE_OVERRIDE;
 
     // get data
     int GetData(unsigned char * pBuffer, int nBlocks, int * pBlocksRetrieved) APE_OVERRIDE;
@@ -197,8 +224,11 @@ public:
     int GetHeaderData(unsigned char * pBuffer) APE_OVERRIDE;
     int GetTerminatingData(unsigned char * pBuffer) APE_OVERRIDE;
 
+    // get other properties
+    bool GetFloat() APE_OVERRIDE { return (m_wfeSource.wFormatTag == WAVE_FORMAT_IEEE_FLOAT); }
+
     // endian
-    bool GetIsBigEndian();
+    bool GetIsBigEndian() const;
 
 private:
     int AnalyzeSource();
@@ -213,11 +243,4 @@ private:
     bool m_bIsValid;
 };
 
-/**************************************************************************************************
-Input souce creation
-**************************************************************************************************/
-CInputSource * CreateInputSource(const wchar_t * pSourceName, WAVEFORMATEX * pwfeSource, int64 * pTotalBlocks, int64 * pHeaderBytes, int64 * pTerminatingBytes, int32 * pFlags, int * pErrorCode = APE_NULL);
-
-#pragma pack(pop)
-
 }
